/*
 * JNpp - Java bindings for NPP, to be used with JCuda
 *
 * Copyright (c) 2010-2012 Marco Hutter - http://www.jcuda.org
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
package jcuda.jnpp;

import jcuda.*;
import jcuda.jnpp.types.*;

/**
 * Java bindings for NPPI. Most of the documentation is extracted
 * from the NPPI header files.
 */
public class JNppi
{

    /**
     * The flag that indicates whether the native library has been
     * loaded
     */
    private static boolean initialized = false;

    /**
     * Whether a CudaException should be thrown if a method is about
     * to set a result code that indicates an error
     */
    private static boolean exceptionsEnabled = false;

    /**
     * Private constructor to prevent instantiation
     */
    private JNppi()
    {
    }

    // Initialize the native library.
    static
    {
        initialize();
    }

    /**
     * Initializes the native library. Note that this method
     * does not have to be called explicitly, since it will
     * be called automatically when this class is loaded.
     */
    public static void initialize()
    {
        if (!initialized)
        {
            LibUtils.loadLibrary("Jnppi");
            initialized = true;
        }
    }



    /**
     * Set the specified log level for the JNppi library.<br />
     * <br />
     * Currently supported log levels:
     * <br />
     * LOG_QUIET: Never print anything <br />
     * LOG_ERROR: Print error messages <br />
     * LOG_TRACE: Print a trace of all native function calls <br />
     *
     * @param logLevel The log level to use.
     */
    public static void setLogLevel(LogLevel logLevel)
    {
        setLogLevelNative(logLevel.ordinal());
    }

    private static native void setLogLevelNative(int logLevel);


    /**
     * Enables or disables exceptions. By default, the methods of this class
     * only return the {@link NppStatus} from the native method.
     * If exceptions are enabled, a CudaException with a detailed error
     * message will be thrown if a method is about to return a result code
     * that indicates an error
     *
     * @param enabled Whether exceptions are enabled
     */
    public static void setExceptionsEnabled(boolean enabled)
    {
        exceptionsEnabled = enabled;
    }

    /**
     * If the given result is a NppStatus that indicates an error
     * and exceptions have been enabled, this method will throw a
     * CudaException with an error message that corresponds to the
     * given result code. Otherwise, the given result is simply
     * returned.
     *
     * @param result The result to check
     * @return The result that was given as the parameter
     * @throws CudaException If exceptions have been enabled and
     * the given result code indicates an error
     */
    private static int checkResult(int result)
    {
        if (exceptionsEnabled && result < 0)
        {
            throw new CudaException(NppStatus.stringFor(result));
        }
        return result;
    }

    /**
     * If the given result is <code>null</code> and exceptions are
     * enabled, then this method will throw a CudaException with
     * an error message stating that a memory allocation failed.
     * Otherwise, the result is simply returned.
     *
     * @param <T> The type of the pointer
     * @param result The result
     * @return The result that was given as a parameter
     * @throws CudaException If exceptions have been enabled and
     * the given result was <code>null</code>
     */
    private static <T extends TypedPointer<?>> T checkResult(T result)
    {
        if (exceptionsEnabled && result == null)
        {
            throw new CudaException("Failed to allocate memory");
        }
        return result;
    }




    //=== Auto-generated part ================================================

    /**
     * <pre>
     * 8-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp8u> nppiMalloc_8u_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_8u_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp8u> nppiMalloc_8u_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 8-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp8u> nppiMalloc_8u_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_8u_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp8u> nppiMalloc_8u_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 8-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp8u> nppiMalloc_8u_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_8u_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp8u> nppiMalloc_8u_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp8u> nppiMalloc_8u_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_8u_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp8u> nppiMalloc_8u_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 16-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16u> nppiMalloc_16u_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_16u_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16u> nppiMalloc_16u_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 16-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16u> nppiMalloc_16u_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_16u_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16u> nppiMalloc_16u_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 16-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16u> nppiMalloc_16u_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_16u_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16u> nppiMalloc_16u_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16u> nppiMalloc_16u_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_16u_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16u> nppiMalloc_16u_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 16-bit signed image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16s_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_16s_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16s_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    public static TypedPointer<Npp16s> nppiMalloc_16s_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_16s_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16s_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 16-bit signed image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16s_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_16s_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16s_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 1 channel 16-bit signed complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16sc_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_16sc_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16sc_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 16-bit signed complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16sc_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_16sc_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16sc_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 16-bit signed complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16sc_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_16sc_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16sc_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 16-bit signed complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppiMalloc_16sc_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_16sc_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp16s> nppiMalloc_16sc_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 32-bit signed image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32s_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32s_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32s_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 32-bit signed image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32s_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32s_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32s_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 32-bit signed image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32s_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32s_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32s_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 32-bit integer complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32sc_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32sc_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32sc_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 32-bit integer complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32sc_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32sc_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32sc_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 32-bit integer complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32sc_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32sc_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32sc_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 32-bit integer complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppiMalloc_32sc_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32sc_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32s> nppiMalloc_32sc_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 32-bit floating point image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32f_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32f_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32f_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 32-bit floating point image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32f_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32f_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32f_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 32-bit floating point image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32f_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32f_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32f_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 32-bit floating point image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32f_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32f_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32f_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    public static TypedPointer<Npp32f> nppiMalloc_32fc_C1(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32fc_C1Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32fc_C1Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 2 channel 32-bit float complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32fc_C2(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32fc_C2Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32fc_C2Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 3 channel 32-bit float complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32fc_C3(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32fc_C3Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32fc_C3Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    /**
     * <pre>
     * 4 channel 32-bit float complex image memory allocator.
     * @param nWidthPixels Image width.
     * @param nHeightPixels Image height.
     * @param pStepBytes \ref line_step.
     * @return
     *  Pointer to new image data.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppiMalloc_32fc_C4(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes)
    {
        return checkResult(nppiMalloc_32fc_C4Native(nWidthPixels, nHeightPixels, pStepBytes));
    }
    private static native TypedPointer<Npp32f> nppiMalloc_32fc_C4Native(
        int nWidthPixels, 
        int nHeightPixels, 
        int[] pStepBytes);


    ///@} Malloc
    /**
     * <pre>
     * Free method for any 2D allocated memory.
     * This method should be used to free memory allocated with any of the nppiMalloc_<modifier> methods.
     * @param pData A pointer to memory allocated using nppiMalloc_<modifier>.
     * </pre>
     */
    public static void nppiFree(
        Pointer pData)
    {
        nppiFreeNative(pData);
    }
    private static native void nppiFreeNative(
        Pointer pData);


    ///@} Image-Memory Management
    /**
     * <pre>
     * @defgroup image_data_exchange_and_initialization Data-Exchange and Initialization
     *
     * Primitives for initializtion, copying and converting image data.
     *
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * @name Image-Memory Set
     * Set methods for images of various types. Images are passed to these primitives via a pointer
     * to the image data (first pixel in the ROI) and a step-width, i.e. the number of bytes between
     * successive lines. The size of the area to be set (region-of-interest, ROI) is specified via
     * a NppiSize struct. 
     * In addition to the image data and ROI, all methods have a parameter to specify the value being
     * set. In case of single channel images this is a single value, in case of multi-channel, an 
     * array of values is passed. 
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * 8-bit image set.
     * @param nValue The pixel value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8s_C1R(
        byte nValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_8s_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8s_C1RNative(
        byte nValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 8-bit two-channel image set.
     * @param aValue The pixel value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8s_C2R(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_8s_C2RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8s_C2RNative(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 8-bit three-channel image set.
     * @param aValue The pixel value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8s_C3R(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_8s_C3RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8s_C3RNative(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 8-bit four-channel image set.
     * @param aValue The pixel value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8s_C4R(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_8s_C4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8s_C4RNative(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 8-bit four-channel image set ignoring alpha channel.
     * @param aValue The pixel value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8s_AC4R(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_8s_AC4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8s_AC4RNative(
        byte[] aValue, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 8-bit unsigned image set.
     * @param nValue The pixel value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_C1R(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_8u_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8u_C1RNative(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 8-bit unsigned image set. 
     * The 8-bit mask image affects setting of the respective pixels in the destination image.
     * If the mask value is zero (0) the pixel is not set, if the mask is non-zero, the corresponding
     * destination pixel is set to specified value.
     * @param nValue The pixel value to be set.
     * @param pDst Pointer \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_C1MR(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_8u_C1MRNative(nValue, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_8u_C1MRNative(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image set.
     * @param aValues Four-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_C4R(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_8u_C4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8u_C4RNative(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 8-bit unsigned image set.
     * @param aValues Four-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_C4MR(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_8u_C4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_8u_C4MRNative(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_AC4R(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_8u_AC4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8u_AC4RNative(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 8-bit unsigned image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_AC4MR(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_8u_AC4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_8u_AC4MRNative(
        byte[] aValues, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image set affecting only single channel.
     * For RGBA images, this method allows setting of a single of the four (RGBA) values 
     * without changing the contents of the other three channels. The channel is selected
     * via the pDst pointer. The pointer needs to point to the actual first value to be set,
     * e.g. in order to set the R-channel (first channel), one would pass pDst unmodified, since
     * its value actually points to the r channel. If one wanted to modify the B channel (second
     * channel), one would pass pDst + 2 to the function.
     * @param nValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_8u_C4CR(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_8u_C4CRNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_8u_C4CRNative(
        byte nValue, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit unsigned image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_C1R(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16u_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16u_C1RNative(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 16-bit unsigned image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_C1MR(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_16u_C1MRNative(nValue, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16u_C1MRNative(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 2 channel 16-bit unsigned image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_C2R(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16u_C2RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16u_C2RNative(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_C4R(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16u_C4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16u_C4RNative(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 16-bit unsigned image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_C4MR(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_16u_C4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16u_C4MRNative(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_AC4R(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16u_AC4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16u_AC4RNative(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 16-bit unsigned image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_AC4MR(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_16u_AC4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16u_AC4MRNative(
        short[] aValues, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image set affecting only single channel.
     * For RGBA images, this method allows setting of a single of the four (RGBA) values 
     * without changing the contents of the other three channels. The channel is selected
     * via the pDst pointer. The pointer needs to point to the actual first value to be set,
     * e.g. in order to set the R-channel (first channel), one would pass pDst unmodified, since
     * its value actually points to the r channel. If one wanted to modify the B channel (second
     * channel), one would pass pDst + 2 to the function.
     * @param nValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16u_C4CR(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16u_C4CRNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16u_C4CRNative(
        short nValue, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C1R(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16s_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16s_C1RNative(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 16-bit image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C1MR(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_16s_C1MRNative(nValue, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16s_C1MRNative(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 2 channel 16-bit image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C2R(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16s_C2RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16s_C2RNative(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C4R(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16s_C4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16s_C4RNative(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 16-bit image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C4MR(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_16s_C4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16s_C4MRNative(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 16-bit image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_AC4R(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16s_AC4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16s_AC4RNative(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 16-bit image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_AC4MR(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_16s_AC4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_16s_AC4MRNative(
        short[] aValues, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image set affecting only single channel.
     * For RGBA images, this method allows setting of a single of the four (RGBA) values 
     * without changing the contents of the other three channels. The channel is selected
     * via the pDst pointer. The pointer needs to point to the actual first value to be set,
     * e.g. in order to set the R-channel (first channel), one would pass pDst unmodified, since
     * its value actually points to the r channel. If one wanted to modify the B channel (second
     * channel), one would pass pDst + 2 to the function.
     * @param nValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16s_C4CR(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16s_C4CRNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16s_C4CRNative(
        short nValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit complex integer image set.
     * @param oValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16sc_C1R(
        Npp16sc oValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16sc_C1RNative(oValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16sc_C1RNative(
        Npp16sc oValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit complex integer two-channel image set.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16sc_C2R(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16sc_C2RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16sc_C2RNative(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit complex integer three-channel image set.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16sc_C3R(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16sc_C3RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16sc_C3RNative(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit complex integer four-channel image set ignoring alpha.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16sc_AC4R(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16sc_AC4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16sc_AC4RNative(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit complex integer four-channel image set.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_16sc_C4R(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_16sc_C4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_16sc_C4RNative(
        Npp16sc[] aValue, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_C1R(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32s_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32s_C1RNative(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 32-bit image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_C1MR(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_32s_C1MRNative(nValue, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32s_C1MRNative(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 32-bit image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_C4R(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32s_C4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32s_C4RNative(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 32-bit image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_C4MR(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_32s_C4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32s_C4MRNative(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 16-bit image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_AC4R(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32s_AC4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32s_AC4RNative(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 16-bit image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_AC4MR(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_32s_AC4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32s_AC4MRNative(
        int[] aValues, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 32-bit unsigned image set affecting only single channel.
     * For RGBA images, this method allows setting of a single of the four (RGBA) values 
     * without changing the contents of the other three channels. The channel is selected
     * via the pDst pointer. The pointer needs to point to the actual first value to be set,
     * e.g. in order to set the R-channel (first channel), one would pass pDst unmodified, since
     * its value actually points to the r channel. If one wanted to modify the B channel (second
     * channel), one would pass pDst + 2 to the function.
     * @param nValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32s_C4CR(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32s_C4CRNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32s_C4CRNative(
        int nValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 32-bit complex integer image set.
     * @param oValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32sc_C1R(
        Npp32sc oValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32sc_C1RNative(oValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32sc_C1RNative(
        Npp32sc oValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two channel 32-bit complex integer image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32sc_C2R(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32sc_C2RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32sc_C2RNative(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 32-bit complex integer image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32sc_C3R(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32sc_C3RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32sc_C3RNative(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 32-bit complex integer image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32sc_C4R(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32sc_C4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32sc_C4RNative(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit complex integer four-channel image set ignoring alpha.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32sc_AC4R(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32sc_AC4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32sc_AC4RNative(
        Npp32sc[] aValue, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit floating point image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_C1R(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32f_C1RNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32f_C1RNative(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 32-bit floating point image set.
     * @param nValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_C1MR(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_32f_C1MRNative(nValue, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32f_C1MRNative(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 32-bit floating point image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_C4R(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32f_C4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32f_C4RNative(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 32-bit floating point image set.
     * @param aValues New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_C4MR(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_32f_C4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32f_C4MRNative(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 32-bit floating point image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_AC4R(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32f_AC4RNative(aValues, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32f_AC4RNative(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Masked 4 channel 32-bit floating point image set method, not affecting Alpha channel.
     * For RGBA images, this method allows setting of the RGB values without changing the contents
     * of the alpha-channel (fourth channel).
     * @param aValues Three-channel array containing the pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the mask image. This is a single channel 8-bit unsigned int image.
     * @param nMaskStep Number of bytes between line starts of successive lines in the mask image.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_AC4MR(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiSet_32f_AC4MRNative(aValues, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiSet_32f_AC4MRNative(
        float[] aValues, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * 4 channel 32-bit floating point image set affecting only single channel.
     * For RGBA images, this method allows setting of a single of the four (RGBA) values 
     * without changing the contents of the other three channels. The channel is selected
     * via the pDst pointer. The pointer needs to point to the actual first value to be set,
     * e.g. in order to set the R-channel (first channel), one would pass pDst unmodified, since
     * its value actually points to the r channel. If one wanted to modify the B channel (second
     * channel), one would pass pDst + 2 to the function.
     * @param nValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32f_C4CR(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32f_C4CRNative(nValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32f_C4CRNative(
        float nValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single channel 32-bit complex image set.
     * @param oValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32fc_C1R(
        Npp32fc oValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32fc_C1RNative(oValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32fc_C1RNative(
        Npp32fc oValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two channel 32-bit complex image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32fc_C2R(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32fc_C2RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32fc_C2RNative(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three channel 32-bit complex image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32fc_C3R(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32fc_C3RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32fc_C3RNative(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four channel 32-bit complex image set.
     * @param aValue The pixel-value to be set.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32fc_C4R(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32fc_C4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32fc_C4RNative(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit complex four-channel image set ignoring alpha.
     * @param aValue New pixel value.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSet_32fc_AC4R(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSet_32fc_AC4RNative(aValue, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSet_32fc_AC4RNative(
        Npp32fc[] aValue, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    ///@}
    /**
     * <pre>
     * @name Image-Memory Copy
     * Copy methods for images of various types. In addition to routines for
     * copying pixels of identical layout from one image to another, there are
     * copy routines for select channels as well as packed-planar conversions:
     * - Select channel to multi-channel copy. E.g. given a three-channel source
     *      and destination image one may copy the second channel of the source
     *      to the third channel of the destination.
     * - Single channel to multi-channel copy. E.g. given a single-channel source
     *      and a four-channel destination, one may copy the contents of the single-
     *      channel source to the second channel of the destination.
     * - Select channel to single-channel copy. E.g. given a three-channel source
     *      and a single-channel destination one may copy the third channel of the 
     *      source to the destination.
     * - Multi-channel to planar copy. These copy operations split a multi-channel
     *      image into a set of single-channel images.
     * - Planar image to multi-channel copy. These copy routines combine separate
     *      color-planes (single channel images) into a single multi-channel image.
     * 
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * 8-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8s_C1R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8s_C1RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two-channel 8-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8s_C2R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8s_C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8s_C2RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 8-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8s_C3R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8s_C3RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 8-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8s_C4R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8s_C4RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 8-bit image copy, ignoring alpha channel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8s_AC4R(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8s_AC4RNative(
        TypedPointer<Npp8s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 8-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image copy, not affecting Alpha channel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image copy, not affecting Alpha channel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit image copy, not affecting Alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16sc_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16sc_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16sc_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two-channel 16-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16sc_C2R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16sc_C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16sc_C2RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 16-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16sc_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16sc_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16sc_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 16-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16sc_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16sc_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16sc_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 16-bit complex image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16sc_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16sc_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16sc_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 32-bit image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 32-bit image copy, not affecting Alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32sc_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32sc_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32sc_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two-channel 32-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32sc_C2R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32sc_C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32sc_C2RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32sc_C3R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32sc_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32sc_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32sc_C4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32sc_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32sc_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit complex image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32sc_AC4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32sc_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32sc_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit floating point image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 32-bit floating point image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 32-bit floating point image copy, not affecting Alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit floating-point complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32fc_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32fc_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Two-channel 32-bit floating-point complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32fc_C2R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32fc_C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32fc_C2RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit floating-point complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32fc_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32fc_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit floating-point complex image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32fc_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32fc_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit floating-point complex image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32fc_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32fc_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * \ref masked_operation 8-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C1MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_8u_C1MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_8u_C1MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation three channel 8-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C3MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_8u_C3MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_8u_C3MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 8-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C4MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_8u_C4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_8u_C4MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 8-bit unsigned image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_AC4MR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_8u_AC4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_8u_AC4MRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation 16-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C1MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_16u_C1MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16u_C1MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation three channel 16-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C3MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_16u_C3MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16u_C3MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 16-bit unsigned image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C4MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_16u_C4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16u_C4MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 16-bit unsigned image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_AC4MR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_16u_AC4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16u_AC4MRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation 16-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C1MR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_16s_C1MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16s_C1MRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation three channel 16-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C3MR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_16s_C3MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16s_C3MRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 16-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C4MR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_16s_C4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16s_C4MRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 16-bit signed image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_AC4MR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_16s_AC4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_16s_AC4MRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation 32-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C1MR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_32s_C1MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32s_C1MRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation three channel 32-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C3MR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_32s_C3MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32s_C3MRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 32-bit signed image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C4MR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_32s_C4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32s_C4MRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 32-bit signed image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_AC4MR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_32s_AC4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32s_AC4MRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation 32-bit float image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C1MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_32f_C1MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32f_C1MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation three channel 32-bit float image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C3MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_32f_C3MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32f_C3MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 32-bit float image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C4MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_32f_C4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32f_C4MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * \ref masked_operation four channel 32-bit float image copy, ignoring alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_AC4MR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep)
    {
        return checkResult(nppiCopy_32f_AC4MRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, nMaskStep));
    }
    private static native int nppiCopy_32f_AC4MRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep);


    /**
     * <pre>
     * Select-channel 8-bit unsigned image copy for three-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C3CR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_C3CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C3CRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 8-bit unsigned image copy for four-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C4CR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_C4CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C4CRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 16-bit signed image copy for three-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C3CR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_C3CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C3CRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 16-bit signed image copy for four-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C4CR(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_C4CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C4CRNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 16-bit unsigned image copy for three-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C3CR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_C3CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C3CRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 16-bit unsigned image copy for four-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C4CR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_C4CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C4CRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 32-bit signed image copy for three-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C3CR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_C3CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C3CRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 32-bit signed image copy for four-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C4CR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_C4CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C4CRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 32-bit float image copy for three-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C3CR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_C3CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C3CRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Select-channel 32-bit float image copy for four-channel images.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref select_destination_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C4CR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_C4CRNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C4CRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel to single-channel 8-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C3C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_C3C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C3C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel to single-channel 8-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C4C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_C4C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C4C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel to single-channel 16-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C3C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_C3C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C3C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel to single-channel 16-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C4C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_C4C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C4C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel to single-channel 16-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C3C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_C3C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C3C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel to single-channel 16-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C4C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_C4C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C4C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel to single-channel 32-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C3C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_C3C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C3C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel to single-channel 32-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C4C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_C4C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C4C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel to single-channel 32-bit float image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C3C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_C3C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C3C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel to single-channel 32-bit float image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C4C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_C4C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C4C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to three-channel 8-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C1C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_C1C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C1C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to four-channel 8-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C1C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_C1C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C1C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to three-channel 16-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C1C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_C1C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C1C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to four-channel 16-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C1C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_C1C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C1C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to three-channel 16-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C1C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_C1C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C1C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to four-channel 16-bit unsigned image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C1C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_C1C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C1C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to three-channel 32-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C1C3R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_C1C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C1C3RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to four-channel 32-bit signed image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C1C4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_C1C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C1C4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to three-channel 32-bit float image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C1C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_C1C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C1C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Single-channel to four-channel 32-bit float image copy.
     * @param pSrc \ref select_source_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C1C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_C1C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C1C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 8-bit unsigned packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_C3P3RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 8-bit unsigned packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_C4P4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_C4P4RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_C4P4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 16-bit signed packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C3P3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_C3P3RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C3P3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 16-bit signed packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_C4P4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_C4P4RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_C4P4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 16-bit unsigned packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C3P3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_C3P3RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C3P3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 16-bit unsigned packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_C4P4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_C4P4RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_C4P4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit signed packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C3P3R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_C3P3RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C3P3RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit signed packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_C4P4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_C4P4RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_C4P4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit float packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C3P3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_C3P3RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C3P3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit float packed to planar image copy.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param aDst Planar \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_C4P4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_C4P4RNative(pSrc, nSrcStep, aDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_C4P4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f>[] aDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 8-bit unsigned planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_P3C3R(
        TypedPointer<Npp8u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_P3C3RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_P3C3RNative(
        TypedPointer<Npp8u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 8-bit unsigned planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_8u_P4C4R(
        TypedPointer<Npp8u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_8u_P4C4RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_8u_P4C4RNative(
        TypedPointer<Npp8u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 16-bit unsigned planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_P3C3R(
        TypedPointer<Npp16u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_P3C3RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_P3C3RNative(
        TypedPointer<Npp16u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 16-bit unsigned planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16u_P4C4R(
        TypedPointer<Npp16u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16u_P4C4RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16u_P4C4RNative(
        TypedPointer<Npp16u>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 16-bit signed planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_P3C3R(
        TypedPointer<Npp16s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_P3C3RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_P3C3RNative(
        TypedPointer<Npp16s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 16-bit signed planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_16s_P4C4R(
        TypedPointer<Npp16s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_16s_P4C4RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_16s_P4C4RNative(
        TypedPointer<Npp16s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit signed planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_P3C3R(
        TypedPointer<Npp32s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_P3C3RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_P3C3RNative(
        TypedPointer<Npp32s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit signed planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32s_P4C4R(
        TypedPointer<Npp32s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32s_P4C4RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32s_P4C4RNative(
        TypedPointer<Npp32s>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three-channel 32-bit float planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_P3C3R(
        TypedPointer<Npp32f>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_P3C3RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_P3C3RNative(
        TypedPointer<Npp32f>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four-channel 32-bit float planar to packed image copy.
     * @param aSrc Planar \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopy_32f_P4C4R(
        TypedPointer<Npp32f>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiCopy_32f_P4C4RNative(aSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiCopy_32f_P4C4RNative(
        TypedPointer<Npp32f>[] aSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    ///@}
    /**
     * <pre>
     * @name Bit-Depth Conversion
     * Convert bit-depth up and down.
     *
     * The integer conversion methods do not involve any scaling. Conversions that reduce bit-depth saturate
     * values exceeding the reduced range to the range's maximum/minimum value.
     * When converting from floating-point values to integer values, a rounding mode can be specified. After rounding
     * to integer values the values get saturated to the destination data type's range.
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned to 16-bit unsigned conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_8u16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit unsigned to 8-bit unsigned conversion.
     * For detailed documentation see nppiConvert_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u8u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_16u8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u8u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned to 16-bit unsigned  conversion.
     * For detailed documentation see nppiConvert_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_8u16u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit unsigned to 8-bit unsigned conversion.
     * For detailed documentation see nppiConvert_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u8u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_16u8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u8u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned to 16-bit unsigned conversion, not affecting Alpha.
     * For detailed documentation see nppiConvert_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_8u16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit unsigned to 8-bit unsigned conversion, not affecting Alpha.
     * For detailed documentation see nppiConvert_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u8u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_16u8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u8u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 8-bit unsigned to 16-bit signed conversion.
     * For detailed documentation see nppiConvert_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16s_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_8u16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16s_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit signed to 8-bit unsigned conversion.
     * For detailed documentation see nppiConvert_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s8u_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_16s8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s8u_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned to 16-bit signed conversion.
     * For detailed documentation see nppiConvert_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16s_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_8u16s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16s_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit signed to 8-bit unsignedconversion, not affecting Alpha.
     * For detailed documentation see nppiConvert_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s8u_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_16s8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s8u_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned to 16-bit signed conversion, not affecting Alpha.
     * For detailed documentation see nppiConverte_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u16s_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_8u16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u16s_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 16-bit signed to 8-bit unsigned conversion, not affecting Alpha.
     * For detailed documentation see nppiConverte_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s8u_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_16s8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s8u_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit singedto 32-bit floating point conversion.
     * For detailed documentation see nppiConverte_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s32f_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_16s32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s32f_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit floating point to 16-bit conversion.
     * For detailed documentation see nppiConverte_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f16s_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return checkResult(nppiConvert_32f16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f16s_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * 8-bit unsigned to 32-bit floating point conversion.
     * For detailed documentation see nppiConverte_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_8u32f_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_8u32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_8u32f_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit unsigned to 32-bit floating point conversion.
     * For detailed documentation see nppiConverte_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u32f_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_16u32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u32f_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit floating point to 16-bit unsigned conversion.
     * For detailed documentation see nppiConverte_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f16u_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return checkResult(nppiConvert_32f16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f16u_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * 32-bit floating point to 8-bit unsigned conversion.
     * For detailed documentation see nppiConverte_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eRoundMode Flag specifying how fractional float values are rounded to integer values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_32f8u_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode)
    {
        return checkResult(nppiConvert_32f8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, eRoundMode));
    }
    private static native int nppiConvert_32f8u_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eRoundMode);


    /**
     * <pre>
     * 16-bit unsigned to 32-bit signed conversion.
     * For detailed documentation see nppiConverte_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16u32s_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_16u32s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16u32s_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 16-bit to 32-bit  conversion.
     * For detailed documentation see nppiConvert_8u16u_C1R().
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiConvert_16s32s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiConvert_16s32s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiConvert_16s32s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    ///@}
    /** @name Copy Const Border
     * Methods for copying images and padding borders with a constant, user-specifiable color.
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned image copy width constant border color.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSizeROI Size of the source region of pixels.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstSizeROI Size (width, height) of the destination region, i.e. the region that gets filled with
     *      data from the source image (inner part) and constant border color (outer part).
     * @param nTopBorderHeight Height (in pixels) of the top border. The height of the border at the bottom of the
     *      destination ROI is implicitly defined by the size of the source ROI: 
     *      nBottomBorderHeight = oDstSizeROI.height - nTopBorderHeight - oSrcSizeROI.height.
     * @param nLeftBorderWidth Width (in pixels) of the left border. The width of the border at the right side of the
     *      destination ROI is implicitly defined by the size of the source ROI:
     *      nRightBorderWidth = oDstSizeROI.width - nLeftBorderWidth - oSrcSizeROI.width.
     * @param nValue The pixel value to be set for border pixels.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopyConstBorder_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte nValue)
    {
        return checkResult(nppiCopyConstBorder_8u_C1RNative(pSrc, nSrcStep, oSrcSizeROI, pDst, nDstStep, oDstSizeROI, nTopBorderHeight, nLeftBorderWidth, nValue));
    }
    private static native int nppiCopyConstBorder_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte nValue);


    /**
     * <pre>
     * 4channel 8-bit unsigned image copy with constant border color.
     * See nppiCopyConstBorder_8u_C1R() for detailed documentation.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSizeROI Size of the source region-of-interest.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstSizeROI Size of the destination region-of-interest.
     * @param nTopBorderHeight Height of top border.
     * @param nLeftBorderWidth Width of left border.
     * @param aValue Vector of the RGBA values of the border pixels to be set.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopyConstBorder_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte[] aValue)
    {
        return checkResult(nppiCopyConstBorder_8u_C4RNative(pSrc, nSrcStep, oSrcSizeROI, pDst, nDstStep, oDstSizeROI, nTopBorderHeight, nLeftBorderWidth, aValue));
    }
    private static native int nppiCopyConstBorder_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte[] aValue);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image copy with constant border color.
     * See nppiCopyConstBorder_8u_C1R() for detailed documentation.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSizeROI Size of the source region-of-interest.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstSizeROI Size of the destination region-of-interest.
     * @param nTopBorderHeight Height of top border.
     * @param nLeftBorderWidth Width of left border.
     * @param aValue Vector of the RGB values of the border pixels. Because this method does not
     *      affect the destination image's alpha channel, only three components of the border color
     *      are needed.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopyConstBorder_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte[] aValue)
    {
        return checkResult(nppiCopyConstBorder_8u_AC4RNative(pSrc, nSrcStep, oSrcSizeROI, pDst, nDstStep, oDstSizeROI, nTopBorderHeight, nLeftBorderWidth, aValue));
    }
    private static native int nppiCopyConstBorder_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        byte[] aValue);


    /**
     * <pre>
     * 32-bit image copy with constant border color.
     * See nppiCopyConstBorder_8u_C1R() for detailed documentation.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSizeROI Size of the source region-of-interest.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstSizeROI Size of the destination region-of-interest.
     * @param nTopBorderHeight Height of top border.
     * @param nLeftBorderWidth Width of left border.
     * @param nValue Border luminance value.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCopyConstBorder_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        int nValue)
    {
        return checkResult(nppiCopyConstBorder_32s_C1RNative(pSrc, nSrcStep, oSrcSizeROI, pDst, nDstStep, oDstSizeROI, nTopBorderHeight, nLeftBorderWidth, nValue));
    }
    private static native int nppiCopyConstBorder_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        NppiSize oSrcSizeROI, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oDstSizeROI, 
        int nTopBorderHeight, 
        int nLeftBorderWidth, 
        int nValue);


    ///@}
    /**
     * <pre>
     * @name Image Transpose
     * Methods for transposing images of various types. Like matrix transpose, image transpose is a mirror along the image's
     * diagonal (upper-left to lower-right corner).
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * 8-bit image transpose.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst Pointer to the destination ROI.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     *
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiTranspose_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI)
    {
        return checkResult(nppiTranspose_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI));
    }
    private static native int nppiTranspose_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI);


    ///@}
    /**
     * <pre>
     * @name Image Color Channel Swap
     * Methods for exchanging the color channels of an image. The methods support arbitrary permutations of the original
     * channels, including replication.
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * 4 channel 8-bit unsigned swap channels, in-place.
     *
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aDstOrder Integer array describing how channel values are permutated. The n-th entry
     *      of the array contains the number of the channel that is stored in the n-th channel of
     *      the output image. E.g. Given an RGBA image, aDstOrder = [3,2,1,0] converts this to ABGR
     *      channel order.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSwapChannels_8u_C4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int[] aDstOrder)
    {
        return checkResult(nppiSwapChannels_8u_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI, aDstOrder));
    }
    private static native int nppiSwapChannels_8u_C4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int[] aDstOrder);


    ///@}
    ///@} image_data_exchange_and_initialization
    /** @defgroup image_arithmetic Arithmetic and Logical Operations
     */
    ///@{
    /** @name AddC
     * Adds a constant value to each pixel of an image.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_8u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image add constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_C1IRSfs(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_8u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C1IRSfsNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel..
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_8u_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel 8-bit unsigned char in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel..
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_C3IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_8u_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel..
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_8u_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel..
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_AC4IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_8u_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel..
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_8u_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_8u_C4IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_8u_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image add constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16u_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_C3IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16u_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16u_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_AC4IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16u_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16u_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16u_C4IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16u_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image add constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16s_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_C3IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16s_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16s_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_AC4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16s_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16s_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16s_C4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16s_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image add constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_C1IRSfs(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_C1IRSfsNative(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16sc_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_C3IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16sc_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_16sc_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_32s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image add constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32s_C1IRSfs(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_32s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32s_C1IRSfsNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_32s_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32s_C3IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_32s_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_32sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image add constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_C1IRSfs(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_32sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_C1IRSfsNative(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_32sc_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_C3IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_32sc_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha image add constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image add constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAddC_32sc_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAddC_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32f_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image add constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C1IR(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32f_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C1IRNative(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32f_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image add constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C3IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32f_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C3IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32f_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image add constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_AC4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32f_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_AC4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32f_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image add constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32f_C4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32f_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32f_C4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32fc_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image add constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C1IR(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32fc_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C1IRNative(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32fc_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image add constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C3IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32fc_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C3IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32fc_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha in place image add constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_AC4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32fc_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_AC4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image add constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32fc_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image add constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddC_32fc_C4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddC_32fc_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddC_32fc_C4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of AddC
    ///@}
    /** @name MulC
     * Multiplies each pixel of an image by a constant value.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_8u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C1IRSfs(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_8u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C1IRSfsNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_8u_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel 8-bit unsigned char in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C3IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_8u_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_8u_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_AC4IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_8u_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_8u_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_8u_C4IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_8u_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16u_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_C3IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16u_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16u_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_AC4IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16u_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16u_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16u_C4IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16u_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16s_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_C3IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16s_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16s_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_AC4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16s_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16s_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16s_C4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16s_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16sc_C1IRSfs(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_C1IRSfsNative(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16sc_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16sc_C3IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16sc_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_16sc_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_32s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32s_C1IRSfs(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_32s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32s_C1IRSfsNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_32s_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32s_C3IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_32s_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_32sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_C1IRSfs(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_32sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_C1IRSfsNative(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_32sc_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_C3IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_32sc_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha image multiply by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image multiply by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMulC_32sc_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMulC_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32f_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image multiply by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_C1IR(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32f_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C1IRNative(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32f_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image multiply by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_C3IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32f_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C3IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32f_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image multiply by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_AC4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32f_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_AC4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32f_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image multiply by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32f_C4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32f_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32f_C4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32fc_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image multiply by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C1IR(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32fc_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C1IRNative(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32fc_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image multiply by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C3IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32fc_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C3IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32fc_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha in place image multiply by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_AC4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32fc_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_AC4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image multiply by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32fc_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image multiply by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulC_32fc_C4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulC_32fc_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulC_32fc_C4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of MulC
    ///@}
    /** @name MulCScale
     * Multiplies each pixel of an image by a constant value then scales the result by the maximum value for the data bit width.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiply by constant and scale by max bit width value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C1IR(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C1IRNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_8u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel 8-bit unsigned char in place image multiply by constant and scale by max bit width value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C3IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_8u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C3IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_8u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image multiply by constant, scale and scale by max bit width value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_AC4IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_8u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_AC4IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_8u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image multiply by constant and scale by max bit width value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_8u_C4IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_8u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_8u_C4IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiply by constant and scale by max bit width value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_C1IR(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C1IRNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_16u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image multiply by constant and scale by max bit width value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_C3IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_16u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C3IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_16u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image multiply by constant and scale by max bit width value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_AC4IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_16u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_AC4IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image multiply by constant and scale by max bit width value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_16u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image multiply by constant and scale by max bit width value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulCScale_16u_C4IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulCScale_16u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulCScale_16u_C4IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of MulCScale
    ///@}
    /** @name SubC
     * Subtracts a constant value from each pixel of an image.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_8u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image subtract constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C1IRSfs(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_8u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C1IRSfsNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_8u_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel 8-bit unsigned char in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C3IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_8u_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_8u_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_AC4IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_8u_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_8u_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_8u_C4IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_8u_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image subtract constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16u_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C3IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16u_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16u_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_AC4IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16u_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16u_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16u_C4IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16u_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image subtract constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16s_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_C3IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16s_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16s_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_AC4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16s_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16s_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16s_C4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16s_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image subtract constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16sc_C1IRSfs(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_C1IRSfsNative(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16sc_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16sc_C3IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16sc_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_16sc_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_32s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image subtract constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32s_C1IRSfs(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_32s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32s_C1IRSfsNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_32s_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32s_C3IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_32s_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_32sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image subtract constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_C1IRSfs(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_32sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_C1IRSfsNative(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_32sc_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_C3IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_32sc_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha image subtract constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image subtract constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSubC_32sc_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSubC_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32f_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image subtract constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C1IR(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32f_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C1IRNative(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32f_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image subtract constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C3IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32f_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C3IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32f_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image subtract constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_AC4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32f_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_AC4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32f_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image subtract constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32f_C4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32f_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32f_C4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32fc_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image subtract constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_C1IR(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32fc_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C1IRNative(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32fc_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image subtract constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_C3IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32fc_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C3IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32fc_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha in place image subtract constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_AC4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32fc_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_AC4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image subtract constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32fc_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image subtract constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSubC_32fc_C4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSubC_32fc_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSubC_32fc_C4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of SubC
    ///@}
    /** @name DivC
     * Divides each pixel of an image by a constant value.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_8u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image divided by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_C1IRSfs(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_8u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C1IRSfsNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_8u_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel 8-bit unsigned char in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_C3IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_8u_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_8u_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_AC4IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_8u_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_8u_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_8u_C4IRSfs(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_8u_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16u_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image divided by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16u_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16u_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_C3IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16u_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16u_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_AC4IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16u_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16u_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16u_C4IRSfs(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16u_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image divided by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C1IRSfs(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C1IRSfsNative(
        short nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16s_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C3IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16s_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16s_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_AC4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16s_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16s_C4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16s_C4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16s_C4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image divided by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_C1IRSfs(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_C1IRSfsNative(
        Npp16sc nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16sc_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_C3IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16sc_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_16sc_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_32s_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image divided by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32s_C1IRSfs(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_32s_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32s_C1IRSfsNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_32s_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32s_C3IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_32s_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_32sc_C1RSfsNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image divided by constant, scale, then clamp to saturated value.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_C1IRSfs(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_32sc_C1IRSfsNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_C1IRSfsNative(
        Npp32sc nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_32sc_C3RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_C3IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_32sc_C3IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha image divided by constant, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed complex integer (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image divided by constant, scale, then clamp to saturated value.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDivC_32sc_AC4IRSfsNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDivC_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32f_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image divided by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_C1IR(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32f_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C1IRNative(
        float nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32f_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image divided by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_C3IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32f_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C3IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32f_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image divided by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_AC4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32f_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_AC4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32f_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image divided by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32f_C4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32f_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32f_C4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32fc_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image divided by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C1IR(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32fc_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C1IRNative(
        Npp32fc nConstant, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32fc_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image divided by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C3IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32fc_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C3IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32fc_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel with unmodified alpha in place image divided by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_AC4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32fc_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_AC4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel image divided by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32fc_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit complex floating point (32-bit floating point real, 32-bit floating point imaginary) channel in place image divided by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDivC_32fc_C4IR(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDivC_32fc_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDivC_32fc_C4IRNative(
        TypedPointer<Npp32f> pConstants, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of DivC
    ///@}
    /** @name AbsDiffC
     * Determines absolute difference between each pixel of an image and a constant value.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image absolute difference with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiffC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nConstant)
    {
        return checkResult(nppiAbsDiffC_8u_C1RNative(pSrc1, nSrc1Step, pDst, nDstStep, oSizeROI, nConstant));
    }
    private static native int nppiAbsDiffC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte nConstant);


    /**
     * <pre>
     * One 16-bit unsigned short channel image absolute difference with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiffC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nConstant)
    {
        return checkResult(nppiAbsDiffC_16u_C1RNative(pSrc1, nSrc1Step, pDst, nDstStep, oSizeROI, nConstant));
    }
    private static native int nppiAbsDiffC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nConstant);


    /**
     * <pre>
     * One 32-bit floating point channel image absolute difference with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiffC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nConstant)
    {
        return checkResult(nppiAbsDiffC_32f_C1RNative(pSrc1, nSrc1Step, pDst, nDstStep, oSizeROI, nConstant));
    }
    private static native int nppiAbsDiffC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nConstant);


    // end of AbsDiffC
    ///@}
    /** @name Add Image
     * Pixel by pixel addition of two images.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_8u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_8u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_8u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_8u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_8u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_8u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_8u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_8u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16s_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16s_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16s_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16s_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16sc_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16sc_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_16sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_32s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Note: This function is to be deprecated in future NPP releases, use the function above with a scale factor of 0 instead. 
     * 32-bit image add.
     * Add the pixel values of corresponding pixels in the ROI and write them to the output image.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32s_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_32s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32s_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_32s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32s_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_32s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_32sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_32sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_32sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_32sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image addition, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiAdd_32sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiAdd_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32f_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32f_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32f_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32f_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32f_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32f_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32f_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32fc_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32fc_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32fc_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32fc_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32fc_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32fc_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image addition.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32fc_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image addition.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAdd_32fc_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAdd_32fc_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAdd_32fc_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Add Image
    ///@}
    /** @name Add Square Image
     * Pixel by pixel addition of squared pixels from source image to floating point pixel values of destination image.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image squared then added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_8u32f_C1IMR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddSquare_8u32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_8u32f_C1IMRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image squared then added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_8u32f_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddSquare_8u32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_8u32f_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image squared then added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_16u32f_C1IMR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddSquare_16u32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_16u32f_C1IMRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image squared then added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_16u32f_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddSquare_16u32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_16u32f_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel image squared then added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_32f_C1IMR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddSquare_32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_32f_C1IMRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel image squared then added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddSquare_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddSquare_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddSquare_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Add Square Image
    ///@}
    /** @name Add Product Image
     * Pixel by pixel addition of product of pixels from two source images to floating point pixel values of destination image.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image product added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_8u32f_C1IMR(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddProduct_8u32f_C1IMRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_8u32f_C1IMRNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel image product added to in place floating point destination image.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_8u32f_C1IR(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddProduct_8u32f_C1IRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_8u32f_C1IRNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image product added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_16u32f_C1IMR(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddProduct_16u32f_C1IMRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_16u32f_C1IMRNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image product added to in place floating point destination image.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_16u32f_C1IR(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddProduct_16u32f_C1IRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_16u32f_C1IRNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel image product added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_32f_C1IMR(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddProduct_32f_C1IMRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_32f_C1IMRNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel image product added to in place floating point destination image.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddProduct_32f_C1IR(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAddProduct_32f_C1IRNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAddProduct_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Add Product Image
    ///@}
    /** @name Add Weighted Image
     * Pixel by pixel addition of alpha weighted pixel values from a source image to floating point pixel values of destination image.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel alpha weighted image added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_8u32f_C1IMR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return checkResult(nppiAddWeighted_8u32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_8u32f_C1IMRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    /**
     * <pre>
     * One 8-bit unsigned char channel alpha weighted image added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_8u32f_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return checkResult(nppiAddWeighted_8u32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_8u32f_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    /**
     * <pre>
     * One 16-bit unsigned short channel alpha weighted image added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_16u32f_C1IMR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return checkResult(nppiAddWeighted_16u32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_16u32f_C1IMRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    /**
     * <pre>
     * One 16-bit unsigned short channel alpha weighted image added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_16u32f_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return checkResult(nppiAddWeighted_16u32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_16u32f_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    /**
     * <pre>
     * One 32-bit floating point channel alpha weighted image added to in place floating point destination image using filter mask (updates destination when mask is non-zero).
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pMask \ref mask_image_pointer.
     * @param nMaskStep \ref mask_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_32f_C1IMR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return checkResult(nppiAddWeighted_32f_C1IMRNative(pSrc, nSrcStep, pMask, nMaskStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_32f_C1IMRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pMask, 
        int nMaskStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    /**
     * <pre>
     * One 32-bit floating point channel alpha weighted image added to in place floating point destination image.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nAlpha Alpha weight to be applied to source image pixels (0.0F to 1.0F)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAddWeighted_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha)
    {
        return checkResult(nppiAddWeighted_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nAlpha));
    }
    private static native int nppiAddWeighted_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        float nAlpha);


    // end of Add Weighted Image
    ///@}
    /** @name Mul Image
     * Pixel by pixel multiply of two images.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_8u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_8u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_8u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_8u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_8u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_8u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_8u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_8u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16s_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16s_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16s_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16s_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_16sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_32s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Note: This function is to be deprecated in future NPP releases, use the function above with a scale factor of 0 instead.
     * 1 channel 32-bit image multiplication.
     * Multiply corresponding pixels in ROI. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32s_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_32s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32s_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_32s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32s_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_32s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_32sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_32sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_32sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_32sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image multiplication, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiMul_32sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiMul_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32f_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32f_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32f_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32f_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32f_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32f_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32f_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32fc_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32fc_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32fc_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32fc_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32fc_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32fc_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image multiplication.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32fc_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image multiplication.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMul_32fc_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMul_32fc_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMul_32fc_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Mul Image
    ///@}
    /** @name MulScale Image
     * Pixel by pixel multiplies each pixel of two images then scales the result by the maximum value for the data bit width.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_8u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_8u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C3IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_8u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C3IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_AC4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_8u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_8u_C4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_8u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_8u_C4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_16u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_16u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_16u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C3IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_16u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C3IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_16u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_AC4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_16u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_16u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image multiplication then scale by maximum value for pixel bit width.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMulScale_16u_C4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMulScale_16u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiMulScale_16u_C4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of MulScale Image
    ///@}
    /** @name Sub Image
     * Pixel by pixel subtraction of two images.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_8u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_8u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_8u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_8u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_8u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_8u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_8u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_8u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16s_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16s_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16s_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16s_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_16sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_32s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Note: This function is to be deprecated in future NPP releases, use the function above with a scale factor of 0 instead. 
     * 32-bit image subtraction.
     * Subtract pSrc1's pixels from corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_32s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32s_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_32s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32s_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_32s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_32sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_32sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_32sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_32sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image subtraction, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSub_32sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSub_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32f_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32f_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32f_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32f_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32f_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32f_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32f_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32fc_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32fc_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32fc_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32fc_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32fc_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32fc_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image subtraction.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32fc_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image subtraction.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSub_32fc_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSub_32fc_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSub_32fc_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Sub Image
    ///@}
    /** @name Div Image
     * Pixel by pixel division of two images.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_8u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_8u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_8u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_8u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_8u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel with unmodified alpha in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_8u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_8u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_8u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel with unmodified alpha in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16s_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel with unmodified alpha in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16s_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16s_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16s_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short complex number (16-bit real, 16-bit imaginary) channel with unmodified alpha in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_16sc_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_16sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_16sc_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32s_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_32s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32s_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Note: This function is to be deprecated in future NPP releases, use the function above with a scale factor of 0 instead. 
     * 32-bit image division.
     * Divide pixels in pSrc2 by pSrc1's pixels. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32s_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_32s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32s_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32s_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_32s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32s_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32s_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_32s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32s_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_C1RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_32sc_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_C1RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_C1IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_32sc_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_C1IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_C3RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_32sc_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_C3RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_C3IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_32sc_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_C3IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_AC4RSfs(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_32sc_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_AC4RSfsNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 32-bit signed integer complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32sc_AC4IRSfs(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_32sc_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiDiv_32sc_AC4IRSfsNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32f_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32f_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32f_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel with unmodified alpha in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32f_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32f_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32f_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32f_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32f_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32fc_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C1IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32fc_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C1IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C3R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32fc_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C3RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C3IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32fc_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C3IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32fc_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel with unmodified alpha in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_AC4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32fc_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_AC4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel image division.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32fc_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point complex number (32-bit real, 32-bit imaginary) channel in place image division.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_32fc_C4IR(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDiv_32fc_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiDiv_32fc_C4IRNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Div Image
    ///@}
    /** @name Div_Round Image
     * Pixel by pixel division of two images using result rounding modes.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_8u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_8u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_8u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_8u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_8u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_8u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_8u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_8u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16u_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16u_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16u_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16u_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16u_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16u_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16u_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16u_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16s_C1RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16s_C1IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16s_C3RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16s_C3IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16s_AC4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image division with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16s_AC4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16s_C4RSfsNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image division, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rndMode Result Rounding mode to be used (NPP_RND_ZERO, NPP_RND_NEAR, or NP_RND_FINANCIAL)
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDiv_Round_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor)
    {
        return checkResult(nppiDiv_Round_16s_C4IRSfsNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI, rndMode, nScaleFactor));
    }
    private static native int nppiDiv_Round_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int rndMode, 
        int nScaleFactor);


    // end of Div_Round Image
    ///@}
    /** @name Abs Image
     * Absolute value of each pixel value in an image.
     */
    ///@{
    /**
     * <pre>
     * One 16-bit signed short channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit signed short channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C1IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_16s_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C1IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit signed short channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C3R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_16s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C3RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C3IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_16s_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C3IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel image absolute value with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_16s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image absolute value with unmodified alpha.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_AC4IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_16s_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_AC4IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_16s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_16s_C4IR(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_16s_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_16s_C4IRNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image absolute value with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image absolute value with unmodified alpha.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image absolute value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image absolute value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbs_32f_C4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbs_32f_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAbs_32f_C4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Abs Image
    ///@}
    /** @name AbsDiff Image
     * Pixel by pixel absolute difference between two images.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel absolute difference of image1 minus image2.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiff_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbsDiff_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbsDiff_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel absolute difference of image1 minus image2.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiff_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbsDiff_16u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbsDiff_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel absolute difference of image1 minus image2.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAbsDiff_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAbsDiff_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAbsDiff_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    // end of AbsDiff Image
    ///@}
    /** @name Sqr Image
     * Square each pixel in an image.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_8u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_8u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_8u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_8u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_8u_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_8u_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C4RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_8u_C4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C4RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_8u_C4IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_8u_C4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_8u_C4IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16u_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16u_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C4RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16u_C4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C4RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16u_C4IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16u_C4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16u_C4IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16s_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16s_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16s_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16s_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image squared with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16s_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C4RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16s_C4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C4RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image squared, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_16s_C4IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqr_16s_C4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqr_16s_C4IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image squared.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqr_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image squared.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqr_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image squared.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqr_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image squared.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqr_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image squared with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqr_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image squared with unmodified alpha.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqr_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image squared.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqr_32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image squared.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqr_32f_C4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqr_32f_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqr_32f_C4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Sqr Image
    ///@}
    /** @name Sqrt Image
     * Pixel by pixel square root of each pixel in an image.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_8u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_8u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_8u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_8u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_AC4RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_8u_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_AC4RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_8u_AC4IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_8u_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_8u_AC4IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_AC4RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16u_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_AC4RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16u_AC4IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16u_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16u_AC4IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16s_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16s_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image square root, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16s_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_AC4RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16s_AC4RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_AC4RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image square root with unmodified alpha, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_16s_AC4IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiSqrt_16s_AC4IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiSqrt_16s_AC4IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image square root.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqrt_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image square root.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqrt_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image square root.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqrt_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image square root.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqrt_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image square root with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqrt_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image square root with unmodified alpha.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_AC4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqrt_32f_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_AC4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel image square root.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqrt_32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit floating point channel in place image square root.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrt_32f_C4IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiSqrt_32f_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiSqrt_32f_C4IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Sqrt Image
    ///@}
    /** @name Ln Image
     * Pixel by pixel natural logarithm of each pixel in an image.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_8u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_8u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_8u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_8u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_16u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_16u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_16u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_16u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_16s_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_16s_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image natural logarithm, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiLn_16s_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiLn_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image natural logarithm.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLn_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLn_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image natural logarithm.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLn_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLn_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image natural logarithm.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLn_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLn_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image natural logarithm.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLn_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLn_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLn_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Ln Image
    ///@}
    /** @name Exp Image
     * Exponential value of each pixel in an image.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_8u_C1RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_8u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_8u_C1RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_8u_C1IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_8u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_8u_C1IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_8u_C3RSfs(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_8u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_8u_C3RSfsNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_8u_C3IRSfs(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_8u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_8u_C3IRSfsNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16u_C1RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_16u_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16u_C1RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16u_C1IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_16u_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16u_C1IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16u_C3RSfs(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_16u_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16u_C3RSfsNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16u_C3IRSfs(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_16u_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16u_C3IRSfsNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16s_C1RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_16s_C1RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16s_C1RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 16-bit signed short channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16s_C1IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_16s_C1IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16s_C1IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16s_C3RSfs(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_16s_C3RSfsNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16s_C3RSfsNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image exponential, scale by 2^(-nScaleFactor), then clamp to saturated value.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_16s_C3IRSfs(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor)
    {
        return checkResult(nppiExp_16s_C3IRSfsNative(pSrcDst, nSrcDstStep, oSizeROI, nScaleFactor));
    }
    private static native int nppiExp_16s_C3IRSfsNative(
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI, 
        int nScaleFactor);


    /**
     * <pre>
     * One 32-bit floating point channel image exponential.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiExp_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiExp_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit floating point channel in place image exponential.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_32f_C1IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiExp_32f_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiExp_32f_C1IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel image exponential.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiExp_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiExp_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit floating point channel in place image exponential.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiExp_32f_C3IR(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiExp_32f_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiExp_32f_C3IRNative(
        TypedPointer<Npp32f> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Exp Image
    ///@}
    /** @name AndC Image
     * Pixel by pixel logical and of an image with a constant.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical and with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C1IR(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C1IRNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_8u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical and with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C3IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_8u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C3IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical and with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_8u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical and with constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_AC4IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_8u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_AC4IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_8u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical and with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_8u_C4IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_8u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_8u_C4IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical and with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C1IR(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C1IRNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_16u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical and with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C3IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_16u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C3IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical and with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_16u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical and with constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_AC4IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_16u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_AC4IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_16u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical and with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_16u_C4IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_16u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_16u_C4IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_32s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical and with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C1IR(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_32s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_32s_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical and with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C3IR(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_32s_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C3IRNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical and with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_32s_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical and with constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_AC4IR(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_32s_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_AC4IRNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical and with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_32s_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical and with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAndC_32s_C4IR(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAndC_32s_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAndC_32s_C4IRNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of AndC Image
    ///@}
    /** @name OrC Image
     * Pixel by pixel logical or of an image with a constant.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C1IR(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C1IRNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_8u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C3IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_8u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C3IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_8u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical or with constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_AC4IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_8u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_AC4IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_8u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_8u_C4IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_8u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_8u_C4IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C1IR(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C1IRNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_16u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C3IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_16u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C3IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_16u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical or with constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_AC4IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_16u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_AC4IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_16u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_16u_C4IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_16u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_16u_C4IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_32s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C1IR(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_32s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_32s_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C3IR(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_32s_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C3IRNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_32s_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical or with constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_AC4IR(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_32s_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_AC4IRNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_32s_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOrC_32s_C4IR(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOrC_32s_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOrC_32s_C4IRNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of OrC Image
    ///@}
    /** @name XorC Image
     * Pixel by pixel logical exclusive or of an image with a constant.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical exclusive or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C1IR(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C1IRNative(
        byte nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_8u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical exclusive or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C3IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_8u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C3IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical exclusive or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_8u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical exclusive or with constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_AC4IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_8u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_AC4IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_8u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical exclusive or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_8u_C4IR(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_8u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_8u_C4IRNative(
        TypedPointer<Npp8u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical exclusive or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C1IR(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C1IRNative(
        short nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_16u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical exclusive or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C3IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_16u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C3IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical exclusive or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_16u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical exclusive or with constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_AC4IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_16u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_AC4IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_16u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical exclusive or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_16u_C4IR(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_16u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_16u_C4IRNative(
        TypedPointer<Npp16u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_32s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical exclusive or with constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C1IR(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_32s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_32s_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical exclusive or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C3IR(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_32s_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C3IRNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical exclusive or with constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_32s_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical exclusive or with constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_AC4IR(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_32s_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_AC4IRNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical exclusive or with constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_32s_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical exclusive or with constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXorC_32s_C4IR(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXorC_32s_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXorC_32s_C4IRNative(
        TypedPointer<Npp32s> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of XorC Image
    ///@}
    /** @name RShiftC Image
     * Pixel by pixel right shift of an image by a constant value.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image right shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C1IR(
        int nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C1IRNative(
        int nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image right shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C3IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C3IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image right shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image right shift by constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_AC4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_AC4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image right shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8u_C4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8u_C4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit signed char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C1R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C1RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit signed char channel in place image right shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C1IR(
        int nConstant, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit signed char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C3R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8s_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C3RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit signed char channel in place image right shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C3IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8s_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C3IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit signed char channel image right shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_AC4R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8s_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_AC4RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit signed char channel in place image right shift by constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_AC4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8s_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_AC4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit signed char channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C4R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8s_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C4RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit signed char channel in place image right shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_8s_C4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_8s_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_8s_C4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image right shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C1IR(
        int nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C1IRNative(
        int nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image right shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C3IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C3IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image right shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image right shift by constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_AC4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_AC4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image right shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16u_C4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16u_C4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit signed short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C1R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C1RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit signed short channel in place image right shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C1IR(
        int nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit signed short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C3R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16s_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C3RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit signed short channel in place image right shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C3IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16s_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C3IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel image right shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_AC4R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16s_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image right shift by constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_AC4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16s_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_AC4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C4R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16s_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C4RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit signed short channel in place image right shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_16s_C4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_16s_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_16s_C4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_32s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image right shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C1IR(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_32s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_32s_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image right shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C3IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_32s_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C3IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image right shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_32s_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image right shift by constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_AC4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_32s_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_AC4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image right shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_32s_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image right shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRShiftC_32s_C4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRShiftC_32s_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiRShiftC_32s_C4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of RShiftC Image
    ///@}
    /** @name LShiftC Image
     * Pixel by pixel left shift of an image by a constant value.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_8u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image left shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C1IR(
        int nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_8u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C1IRNative(
        int nConstant, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_8u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image left shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C3IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_8u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C3IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image left shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_8u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image left shift by constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_AC4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_8u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_AC4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_8u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image left shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_8u_C4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_8u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_8u_C4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_16u_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image left shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C1IR(
        int nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_16u_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C1IRNative(
        int nConstant, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_16u_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image left shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C3IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_16u_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C3IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image left shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_16u_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image left shift by constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_AC4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_16u_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_AC4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_16u_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image left shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_16u_C4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_16u_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_16u_C4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nConstant Constant.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_32s_C1RNative(pSrc1, nSrc1Step, nConstant, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nConstant, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image left shift by constant.
     * @param nConstant Constant.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C1IR(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_32s_C1IRNative(nConstant, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C1IRNative(
        int nConstant, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_32s_C3RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image left shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C3IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_32s_C3IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C3IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image left shift by constant with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_32s_AC4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image left shift by constant with unmodified alpha.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_AC4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_32s_AC4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_AC4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image left shift by constant.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_32s_C4RNative(pSrc1, nSrc1Step, pConstants, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image left shift by constant.
     * @param pConstants pointer to a list of constant values, one per channel.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiLShiftC_32s_C4IR(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiLShiftC_32s_C4IRNative(pConstants, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiLShiftC_32s_C4IRNative(
        TypedPointer<Npp32u> pConstants, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of LShiftC Image
    ///@}
    /** @name And Image
     * Pixel by pixel logical and of images.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_8u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_8u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C3IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_8u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C3IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical and with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical and with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_AC4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_8u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_8u_C4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_8u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_8u_C4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_16u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_16u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_16u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C3IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_16u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C3IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical and with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_16u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical and with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_AC4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_16u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_16u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_16u_C4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_16u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_16u_C4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C1IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_32s_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C1IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_32s_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C3IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_32s_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C3IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical and with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_32s_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical and with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_AC4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_32s_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_AC4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical and.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_32s_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical and.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAnd_32s_C4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAnd_32s_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAnd_32s_C4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of And Image
    ///@}
    /** @name Or Image
     * Pixel by pixel logical or of images.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_8u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_8u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C3IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_8u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C3IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_AC4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_8u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_8u_C4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_8u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_8u_C4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_16u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_16u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_16u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C3IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_16u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C3IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_16u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_AC4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_16u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_16u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_16u_C4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_16u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_16u_C4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C1IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_32s_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C1IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_32s_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C3IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_32s_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C3IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_32s_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_AC4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_32s_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_AC4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_32s_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiOr_32s_C4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiOr_32s_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiOr_32s_C4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Or Image
    ///@}
    /** @name Xor Image
     * Pixel by pixel logical exclusive or of images.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_8u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C1IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_8u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C1IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_8u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C3IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_8u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C3IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical exclusive or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical exclusive or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_AC4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_8u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_8u_C4IR(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_8u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_8u_C4IRNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_16u_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C1IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_16u_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C1IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_16u_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C3IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_16u_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C3IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical exclusive or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_16u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical exclusive or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_AC4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_16u_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_16u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_16u_C4IR(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_16u_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_16u_C4IRNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_32s_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 32-bit signed integer channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C1IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_32s_C1IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C1IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C3R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_32s_C3RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C3RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 32-bit signed integer channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C3IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_32s_C3IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C3IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical exclusive or with unmodified alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_32s_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical exclusive or with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_AC4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_32s_AC4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_AC4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel image logical exclusive or.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_32s_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 32-bit signed integer channel in place image logical exclusive or.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiXor_32s_C4IR(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiXor_32s_C4IRNative(pSrc, nSrcStep, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiXor_32s_C4IRNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Xor Image
    ///@}
    /** @name Not Image
     * Pixel by pixel logical not of image.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image logical not.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiNot_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image logical not.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C1IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiNot_8u_C1IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C1IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image logical not.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiNot_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image logical not.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C3IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiNot_8u_C3IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C3IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical not with unmodified alpha.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiNot_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical not with unmodified alpha.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiNot_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image logical not.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiNot_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image logical not.
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNot_8u_C4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiNot_8u_C4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiNot_8u_C4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of Not Image
    ///@}
    /** @name AlphaCompC Image
     * Composite two images using constant alpha values.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_8u_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_8u_C3RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_8u_C4RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image composition with alpha using constant source alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_8u_AC4RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 8-bit signed char channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_8s_C1R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8s> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_8s_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_8s_C1RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8s> pSrc2, 
        int nSrc2Step, 
        byte nAlpha2, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 16-bit unsigned short channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_16u_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_16u_C3RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_16u_C4RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image composition with alpha using constant source alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_16u_AC4RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 16-bit signed short channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_16s_C1R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_16s_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_16s_C1RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        short nAlpha2, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit unsigned integer channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_32u_C1R(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        int nAlpha1, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        int nAlpha2, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_32u_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_32u_C1RNative(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        int nAlpha1, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        int nAlpha2, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit signed integer channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_32s_C1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nAlpha1, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        int nAlpha2, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_32s_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_32s_C1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        int nAlpha1, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        int nAlpha2, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit floating point channel image composition using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0.0 - 1.0).
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param nAlpha2 Image alpha opacity (0.0 - 1.0).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaCompC_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nAlpha1, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        float nAlpha2, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaCompC_32f_C1RNative(pSrc1, nSrc1Step, nAlpha1, pSrc2, nSrc2Step, nAlpha2, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaCompC_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        float nAlpha1, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        float nAlpha2, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    // end of AlphaCompC Image
    ///@}
    /** @name AlphaPremulC Image
     * Premultiplies pixels of an image using a constant alpha value.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_8u_C1RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 8-bit unsigned char channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C1IR(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_8u_C1IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C1IRNative(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C3R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_8u_C3RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C3RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 8-bit unsigned char channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C3IR(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_8u_C3IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C3IRNative(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_8u_C4RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_C4IR(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_8u_C4IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_C4IRNative(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image premultiplication with alpha using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_8u_AC4RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        byte nAlpha1, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image premultiplication with alpha using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_8u_AC4IR(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_8u_AC4IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_8u_AC4IRNative(
        byte nAlpha1, 
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_16u_C1RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * One 16-bit unsigned short channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C1IR(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_16u_C1IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C1IRNative(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C3R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_16u_C3RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C3RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Three 16-bit unsigned short channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C3IR(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_16u_C3IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C3IRNative(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image premultiplication using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_16u_C4RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image premultiplication using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_C4IR(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_16u_C4IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_C4IRNative(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image premultiplication with alpha using constant alpha.
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_16u_AC4RNative(pSrc1, nSrc1Step, nAlpha1, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        short nAlpha1, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image premultiplication with alpha using constant alpha.
     * @param nAlpha1 Image alpha opacity (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremulC_16u_AC4IR(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremulC_16u_AC4IRNative(nAlpha1, pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremulC_16u_AC4IRNative(
        short nAlpha1, 
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of AlphaPremulC Image
    ///@}
    /** @name AlphaComp Image
     * Composite two images using alpha opacity values contained in each image.
     */
    ///@{
    /**
     * <pre>
     * One 8-bit unsigned char channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_8u_AC1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_8u_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_8u_AC1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 8-bit unsigned char channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 8-bit signed char channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_8s_AC1R(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_8s_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_8s_AC1RNative(
        TypedPointer<Npp8s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 16-bit unsigned short channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_16u_AC1R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_16u_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_16u_AC1RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_16u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 16-bit signed short channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_16s_AC1R(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_16s_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_16s_AC1RNative(
        TypedPointer<Npp16s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit unsigned integer channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32u_AC1R(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_32u_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32u_AC1RNative(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 32-bit unsigned integer channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32u_AC4R(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_32u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32u_AC4RNative(
        TypedPointer<Npp32u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit signed integer channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32s_AC1R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_32s_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32s_AC1RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 32-bit signed integer channel image composition using image alpha values (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32s_AC4R(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_32s_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32s> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * One 32-bit floating point channel image composition using image alpha values (0.0 - 1.0).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32f_AC1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_32f_AC1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32f_AC1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    /**
     * <pre>
     * Four 32-bit floating point channel image composition using image alpha values (0.0 - 1.0).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eAlphaOp alpha-blending operation..
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaComp_32f_AC4R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp)
    {
        return checkResult(nppiAlphaComp_32f_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eAlphaOp));
    }
    private static native int nppiAlphaComp_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eAlphaOp);


    // end of AlphaComp Image
    ///@}
    /** @name AlphaPremul Image
     * Premultiplies image pixels by image alpha opacity values.
     */
    ///@{
    /**
     * <pre>
     * Four 8-bit unsigned char channel image premultiplication with pixel alpha (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremul_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremul_8u_AC4RNative(pSrc1, nSrc1Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremul_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 8-bit unsigned char channel in place image premultiplication with pixel alpha (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremul_8u_AC4IR(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremul_8u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremul_8u_AC4IRNative(
        TypedPointer<Npp8u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel image premultiplication with pixel alpha (0 - max channel pixel value).
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremul_16u_AC4R(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremul_16u_AC4RNative(pSrc1, nSrc1Step, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremul_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Four 16-bit unsigned short channel in place image premultiplication with pixel alpha (0 - max channel pixel value).
     * @param pSrcDst \ref in_place_image_pointer.
     * @param nSrcDstStep \ref in_place_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiAlphaPremul_16u_AC4IR(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiAlphaPremul_16u_AC4IRNative(pSrcDst, nSrcDstStep, oSizeROI));
    }
    private static native int nppiAlphaPremul_16u_AC4IRNative(
        TypedPointer<Npp16u> pSrcDst, 
        int nSrcDstStep, 
        NppiSize oSizeROI);


    // end of AlphaPremul Image
    ///@}
    // end of Image Arithmetic
    ///@}
    /**
     * <pre>
     * @defgroup image_threshold_and_compare_operations Threshold and Compare Operations
     *
     * Methods for pixel-wise threshold and compare operations.
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * @name Threshold
     *
     * Threshold pixels.
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * 32-bit floating point threshold.
     * If for a comparison operations OP the predicate (sourcePixel OP nThreshold) is true, the pixel is set
     * to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param nThreshold The threshold value.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        int eComparisonOperation)
    {
        return checkResult(nppiThreshold_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, nThreshold, eComparisonOperation));
    }
    private static native int nppiThreshold_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float nThreshold, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image threshold, not affecting Alpha.
     * If for a comparison operations OP the predicate (sourcePixel.channel OP nThreshold) is true, the channel
     * value is set to nThreshold, otherwise it is set to sourcePixel.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aThresholds The threshold values, one per color channel.
     * @param eComparisonOperation The type of comparison operation to be used. The only valid
     *      values are: NPP_CMP_LESS and NPP_CMP_GREATER.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, or NPP_NOT_SUPPORTED_MODE_ERROR if an invalid
     * comparison operation type is specified.
     * </pre>
     */
    public static int nppiThreshold_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] aThresholds, 
        int eComparisonOperation)
    {
        return checkResult(nppiThreshold_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, aThresholds, eComparisonOperation));
    }
    private static native int nppiThreshold_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        byte[] aThresholds, 
        int eComparisonOperation);


    ///@}
    /**
     * <pre>
     * @name Image Compare Methods
     * Compare the pixels of two images and create a binary result image. In case of multi-channel
     * image types, the condition must be fulfilled for all channels, otherwise the comparison
     * is considered false.
     * The "binary" result image is of type 8u_C1. False is represented by 0, true by NPP_MAX_8U.
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * 4 channel 8-bit unsigned image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_8u_C4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return checkResult(nppiCompare_8u_C4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_8u_C4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image compare, not affecting Alpha.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_8u_AC4R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return checkResult(nppiCompare_8u_AC4RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    /**
     * <pre>
     * 32-bit floating point image compare.
     * Compare pSrc1's pixels with corresponding pixels in pSrc2. 
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrc1Step \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrc2Step \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param eComparisonOperation Specifies the comparison operation to be used in the pixel comparison.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiCompare_32f_C1R(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation)
    {
        return checkResult(nppiCompare_32f_C1RNative(pSrc1, nSrc1Step, pSrc2, nSrc2Step, pDst, nDstStep, oSizeROI, eComparisonOperation));
    }
    private static native int nppiCompare_32f_C1RNative(
        TypedPointer<Npp32f> pSrc1, 
        int nSrc1Step, 
        TypedPointer<Npp32f> pSrc2, 
        int nSrc2Step, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        int eComparisonOperation);


    ///@}
    ///@} image_threshold_and_compare_operations
    /**
     * <pre>
     * @defgroup image_statistics_functions Statistics Functions
     *
     * Routines computing statistical image information.
     *
     *
     * </pre>
     */
    ///@{
    /** @name Mean_StdDev
     *  Computes the mean and standard deviation of image pixel values
     */
    ///@{
    /**
     * <pre>
     * Device scratch buffer size (in bytes) for mean and standard deviation of image.
     * This primitive provides the correct buffer size for nppiMean_StdDev_8u_C1R.
     * @param oSizeROI \ref roi_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a 
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppiMeanStdDev8uC1RGetBufferHostSize(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return checkResult(nppiMeanStdDev8uC1RGetBufferHostSizeNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMeanStdDev8uC1RGetBufferHostSizeNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 8-bit unsigned mean standard deviation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     * @param pMean Contains computed mean.
     * @param pStdDev Contains computed standard deviation.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMean_StdDev_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev)
    {
        return checkResult(nppiMean_StdDev_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pMean, pStdDev));
    }
    private static native int nppiMean_StdDev_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        TypedPointer<Npp64f> pMean, 
        TypedPointer<Npp64f> pStdDev);


    ///@}
    /** @name NormDiff
     *  Norm of pixel differences between two images.
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned L1 norm of pixel differences.
     *
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrcStep1 \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrcStep2 \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pRetVal Contains computed L1-norm of differences. This is a host pointer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNormDiff_L1_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal)
    {
        return checkResult(nppiNormDiff_L1_8u_C1RNative(pSrc1, nSrcStep1, pSrc2, nSrcStep2, oSizeROI, pRetVal));
    }
    private static native int nppiNormDiff_L1_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal);


    /**
     * <pre>
     * 8-bit unsigned L2 norm of pixel differences.
     *
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrcStep1 \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrcStep2 \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pRetVal Contains computed L1-norm of differences. This is a host pointer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNormDiff_L2_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal)
    {
        return checkResult(nppiNormDiff_L2_8u_C1RNative(pSrc1, nSrcStep1, pSrc2, nSrcStep2, oSizeROI, pRetVal));
    }
    private static native int nppiNormDiff_L2_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal);


    /**
     * <pre>
     * 8-bit unsigned Infinity Norm of pixel differences.
     *
     * @param pSrc1 \ref source_image_pointer.
     * @param nSrcStep1 \ref source_image_line_step.
     * @param pSrc2 \ref source_image_pointer.
     * @param nSrcStep2 \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param *pRetVal Contains computed L1-norm of differences. This is a host pointer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiNormDiff_Inf_8u_C1R(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal)
    {
        return checkResult(nppiNormDiff_Inf_8u_C1RNative(pSrc1, nSrcStep1, pSrc2, nSrcStep2, oSizeROI, pRetVal));
    }
    private static native int nppiNormDiff_Inf_8u_C1RNative(
        TypedPointer<Npp8u> pSrc1, 
        int nSrcStep1, 
        TypedPointer<Npp8u> pSrc2, 
        int nSrcStep2, 
        NppiSize oSizeROI, 
        TypedPointer<Npp64f> pRetVal);


    ///@}
    /**
     * <pre>
     * SqrIntegral Transforms an image to integral and integral of pixel squares
     * representation. This function assumes that the integral and integral of squares 
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pSqr \ref destination_image_pointer.
     * @param nSqrStep \ref destination_image_line_step.
     * @param oSrcROI \ref roi_specification.
     * @param val The value to add to pDst image pixels
     * @param valSqr The value to add to pSqr image pixels
     * @param integralImageNewHeight Extended height of output surfaces (needed by
     *        transpose in primitive)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSqrIntegral_8u32s32f_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        TypedPointer<Npp32f> pSqr, 
        int nSqrStep, 
        NppiSize oSrcROI, 
        int val, 
        float valSqr, 
        int integralImageNewHeight)
    {
        return checkResult(nppiSqrIntegral_8u32s32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, pSqr, nSqrStep, oSrcROI, val, valSqr, integralImageNewHeight));
    }
    private static native int nppiSqrIntegral_8u32s32f_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        TypedPointer<Npp32f> pSqr, 
        int nSqrStep, 
        NppiSize oSrcROI, 
        int val, 
        float valSqr, 
        int integralImageNewHeight);


    /**
     * <pre>
     * RectStdDev Computes the standard deviation of integral images
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pSqr \ref destination_image_pointer.
     * @param nSqrStep \ref destination_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param rect rectangular window
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRectStdDev_32s32f_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp64f> pSqr, 
        int nSqrStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiRect rect)
    {
        return checkResult(nppiRectStdDev_32s32f_C1RNative(pSrc, nSrcStep, pSqr, nSqrStep, pDst, nDstStep, oSizeROI, rect));
    }
    private static native int nppiRectStdDev_32s32f_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp64f> pSqr, 
        int nSqrStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiRect rect);


    /** @name Sum
     *  Sum of 8 bit images.
     */
    ///@{
    /**
     * <pre>
     * Scratch-buffer size for nppiSum_8u_C1R.
     * 
     * @param oSizeROI ROI size.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiReductionGetBufferHostSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return checkResult(nppiReductionGetBufferHostSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiReductionGetBufferHostSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Scratch-buffer size for nppiSum_8u_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiReductionGetBufferHostSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return checkResult(nppiReductionGetBufferHostSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiReductionGetBufferHostSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 8-bit unsigned image sum with 64-bit long long result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     * @param *pSum Contains computed sum.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSum_8u64s_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        long[] pSum)
    {
        return checkResult(nppiSum_8u64s_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pSum));
    }
    private static native int nppiSum_8u64s_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        long[] pSum);


    /**
     * <pre>
     * 8-bit unsigned image sum with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     * @param *pSum Contains computed sum.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSum_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] pSum)
    {
        return checkResult(nppiSum_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, pSum));
    }
    private static native int nppiSum_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] pSum);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image sum with 64-bit long long result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     * @param aSum Array contains computed sum for each channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSum_8u64s_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        long[] aSum)
    {
        return checkResult(nppiSum_8u64s_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_8u64s_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        long[] aSum);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image sum with 64-bit double precision result.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer
     * @param aSum Array contains computed sum for each channel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSum_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum)
    {
        return checkResult(nppiSum_8u_C4RNative(pSrc, nSrcStep, oSizeROI, pDeviceBuffer, aSum));
    }
    private static native int nppiSum_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pDeviceBuffer, 
        double[] aSum);


    ///@}
    /** @name MinMax
     *  Minimum and maximum of 8-bit images.
     */
    ///@{
    /**
     * <pre>
     * Scratch-buffer size for nppiMinManx_8u_C1R.
     * 
     * @param oSizeROI ROI size.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiMinMaxGetBufferSize_8u_C1R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return checkResult(nppiMinMaxGetBufferSize_8u_C1RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 8-bit unsigned pixel minimum and maximum.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMin Device-memory pointer receiving the minimum result.
     * @param pMax Device-memory pointer receiving the maximum result.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferSize_8u_C1R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMinMax_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMin, 
        TypedPointer<Npp8u> pMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return checkResult(nppiMinMax_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMin, 
        TypedPointer<Npp8u> pMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiMinManx_8u_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiMinMaxGetBufferSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] hpBufferSize)/** host pointer */
    {
        return checkResult(nppiMinMaxGetBufferSize_8u_C4RNative(oSizeROI, hpBufferSize));
    }
    private static native int nppiMinMaxGetBufferSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 4 channel 8-bit unsigned pixel minimum and maximum.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param aMin Device-pointer (array) receiving the minimum result.
     * @param aMax Device-pointer (array) receiving the maximum result.
     * @param pDeviceBuffer Buffer to a scratch memory. Use \ref nppiMinMaxGetBufferSize_8u_C4R to determine
     *          the minium number of bytes required.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *
     * \note Unlike nppiMinMax_8u_C1R, this primitive returns its results as device
     *       pointers.
     * </pre>
     */
    public static int nppiMinMax_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        byte[] aMin, 
        byte[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return checkResult(nppiMinMax_8u_C4RNative(pSrc, nSrcStep, oSizeROI, aMin, aMax, pDeviceBuffer));
    }
    private static native int nppiMinMax_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        byte[] aMin, 
        byte[] aMax, 
        TypedPointer<Npp8u> pDeviceBuffer);


    ///@}
    /** @name Histogram
     */
    ///@{
    /**
     * <pre>
     * Compute levels with even distribution.
     *
     * @param hpLevels A host pointer to array which receives the levels being
     *        computed. The array needs to be of size nLevels.
     * @param nLevels The number of levels being computed. nLevels must be at least
     *        2, otherwise an NPP_HISTO_NUMBER_OF_LEVELS_ERROR error is returned.
     * @param nLowerLevel Lower boundary value of the lowest level.
     * @param nUpperLevel Upper boundary value of the greatest level.
     * @return
     *  Error code.
     * </pre>
     */
    public static int nppiEvenLevelsHost_32s(
        TypedPointer<Npp32s> hpLevels, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel)
    {
        return checkResult(nppiEvenLevelsHost_32sNative(hpLevels, nLevels, nLowerLevel, nUpperLevel));
    }
    private static native int nppiEvenLevelsHost_32sNative(
        TypedPointer<Npp32s> hpLevels, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_8u_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_8u_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramEvenGetBufferSize_8u_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 8-bit unsigned histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param nLevels Number of levels.
     * @param nLowerLevel Lower boundary of lowest level bin.
     * @param nUpperLevel Upper boundary of highest level bin.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_8u_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramEven_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_8u_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramEvenGetBufferSize_8u_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 8-bit unsigned histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_8u_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramEven_8u_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_8u_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramEvenGetBufferSize_8u_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as the last channel) 8-bit unsigned histogram with evenly distributed bins.
     * Alpha channel is ignored during histogram computation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_8u_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramEven_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16u_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16u_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramEvenGetBufferSize_16u_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit unsigned histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param nLevels Number of levels.
     * @param nLowerLevel Lower boundary of lowest level bin.
     * @param nUpperLevel Upper boundary of highest level bin.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16u_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramEven_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16u_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramEvenGetBufferSize_16u_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 16-bit unsigned histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16u_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramEven_16u_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16u_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramEvenGetBufferSize_16u_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as the last channel) 16-bit unsigned histogram with evenly distributed bins.
     * Alpha channel is ignored during histogram computation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16u_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramEven_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16s_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16s_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramEvenGetBufferSize_16s_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param nLevels Number of levels.
     * @param nLowerLevel Lower boundary of lowest level bin.
     * @param nUpperLevel Upper boundary of highest level bin.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16s_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramEven_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        int nLevels, 
        int nLowerLevel, 
        int nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16s_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramEvenGetBufferSize_16s_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 16-bit signed histogram with evenly distributed bins.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16s_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramEven_16s_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramEven_16s_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramEvenGetBufferSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramEvenGetBufferSize_16s_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramEvenGetBufferSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as the last channel) 16-bit signed histogram with evenly distributed bins.
     * Alpha channel is ignored during histogram computation.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving computed histograms per color channel. 
     *      Array pointed by pHist[i] be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param nLowerLevel Array containing lower-level of lowest bin per color channel.
     * @param nUpperLevel Array containing upper-level of highest bin per color channel.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramEvenGetBufferSize_16s_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramEven_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramEven_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, nLevels, nLowerLevel, nUpperLevel, pBuffer));
    }
    private static native int nppiHistogramEven_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        int[] nLevels, 
        int[] nLowerLevel, 
        int[] nUpperLevel, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_8u_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_8u_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_8u_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_8u_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 8-bit unsigned histogram with bins determined by pLevels array.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param pLevels Pointer to array containing the level sizes of the bins.
            The array must be of size nLevels.
     * @param nLevels Number of levels in histogram.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_8u_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_8u_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_8u_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_8u_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_8u_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_8u_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 8-bit unsigned histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_8u_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_8u_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_8u_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_8u_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_8u_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_8u_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as a last channel) 8-bit unsigned histogram with bins determined by pLevels.
     * Alpha channel is ignored during the histograms computations.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_8u_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_8u_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16u_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16u_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_16u_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16u_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit unsigned histogram with bins determined by pLevels array.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param pLevels Pointer to array containing the level sizes of the bins.
            The array must be of size nLevels.
     * @param nLevels Number of levels in histogram.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16u_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_16u_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16u_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16u_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_16u_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16u_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 16-bit unsigned histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16u_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_16u_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16u_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16u_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_16u_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16u_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as a last channel) 16-bit unsigned histogram with bins determined by pLevels.
     * Alpha channel is ignored during the histograms computations.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16u_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_16u_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16s_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16s_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_16s_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16s_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed histogram with bins determined by pLevels array.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param pLevels Pointer to array containing the level sizes of the bins.
            The array must be of size nLevels.
     * @param nLevels Number of levels in histogram.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16s_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_16s_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16s_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16s_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16s_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_16s_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16s_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 16-bit signed histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16s_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16s_C4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_16s_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16s_C4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_16s_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_16s_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_16s_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_16s_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as a last channel) 16-bit signed histogram with bins determined by pLevels.
     * Alpha channel is ignored during the histograms computations.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_16_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_16s_AC4R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_16s_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_16s_AC4RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_32f_C1R.
     * 
     * @param oSizeROI \ref roi_specification.
     * @param nLevels Number of levels in the histogram.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_32f_C1R(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_32f_C1RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_32f_C1RNative(
        NppiSize oSizeROI, 
        int nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float histogram with bins determined by pLevels array.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Pointer to array that receives the computed histogram. 
     *      The array must be of size nLevels-1. 
     * @param pLevels Pointer to array containing the level sizes of the bins.
            The array must be of size nLevels.
     * @param nLevels Number of levels in histogram.
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_32f_C1R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32f> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_32f_C1RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pHist, 
        TypedPointer<Npp32f> pLevels, 
        int nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_32f_C4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_32f_C4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_32f_C4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_32f_C4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel 32-bit float histogram with bins determined by pLevels.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_32f_C4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32f>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_32f_C4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32f>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    /**
     * <pre>
     * Scratch-buffer size for nppiHistogramRange_32f_AC4R.
     * 
     * @param oSizeROI ROI size.
     * @param nLevels Array containing number of levels per color channel.
     * @param hpBufferSize Host pointer where required buffer size is returned.
     * @return
     *  Error Code.
     * </pre>
     */
    public static int nppiHistogramRangeGetBufferSize_32f_AC4R(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize)
    {
        return checkResult(nppiHistogramRangeGetBufferSize_32f_AC4RNative(oSizeROI, nLevels, hpBufferSize));
    }
    private static native int nppiHistogramRangeGetBufferSize_32f_AC4RNative(
        NppiSize oSizeROI, 
        int[] nLevels, 
        int[] hpBufferSize);


    /**
     * <pre>
     * 4 channel (alpha as a last channel) 32-bit float histogram with bins determined by pLevels.
     * Alpha channel is ignored during the histograms computations.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pHist Array of pointers which are receiving the computed histograms per color channel. 
     *      Array pointed by pHist[i] must be of size nLevels[i]-1.
     * @param nLevels Array containing number of levels per color channel. 
     * @param pLevels Array containing pointers to level-arrays per color channel.
            Array pointed by pLevel[i] must be of size nLevels[i].
     * @param pBuffer Pointer to appropriately sized (nppiHistogramRangeGetBufferSize_32f_AC4R) 
     *      scratch buffer.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiHistogramRange_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32f>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer)
    {
        return checkResult(nppiHistogramRange_32f_AC4RNative(pSrc, nSrcStep, oSizeROI, pHist, pLevels, nLevels, pBuffer));
    }
    private static native int nppiHistogramRange_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pHist, 
        TypedPointer<Npp32f>[] pLevels, 
        int[] nLevels, 
        TypedPointer<Npp8u> pBuffer);


    ///@} Histogram group
    ///@} image_statistics_functions
    /**
     * <pre>
     * @defgroup image_filtering_functions Filtering Functions
     *
     * Linear and non-linear image filtering functions.
     *
     *
     * </pre>
     */
    ///@{
    /** @name 1D Linear Filter
     *  1D mask Linear Convolution Filter, with rescaling, for 8 bit images.
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned 1D (column) image convolution.
     * 
     * Apply convolution filter with user specified 1D column of weights.  
     * Result pixel is equal to the sum of the products between the kernel
     * coefficients (pKernel array) and corresponding neighboring column pixel
     * values in the source image defined by nKernelDim and nAnchorY, divided by
     * nDivisor. 
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param pKernel Pointer to the start address of the kernel coefficient array.
     *                Coefficients are expected to be stored in reverse order.
     * @param nMaskSize Length of the linear kernel array.
     * @param nAnchor Y offset of the kernel origin frame of reference w.r.t the
     *                 source pixel.
     * @param nDivisor The factor by which the convolved summation from the Filter
     *                 operation should be divided.  If equal to the sum of
     *                 coefficients, this will keep the maximum result value within
     *                 full scale.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterColumn_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor)
    {
        return checkResult(nppiFilterColumn_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, pKernel, nMaskSize, nAnchor, nDivisor));
    }
    private static native int nppiFilterColumn_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned 1D (column) image convolution.
     * 
     * Apply convolution filter with user specified 1D column of weights.  
     * Result pixel is equal to the sum of the products between the kernel
     * coefficients (pKernel array) and corresponding neighboring column pixel
     * values in the source image defined by nKernelDim and nAnchorY, divided by
     * nDivisor. 
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param pKernel Pointer to the start address of the kernel coefficient array.
     *                Coefficients are expected to be stored in reverse order.
     * @param nMaskSize Length of the linear kernel array.
     * @param nAnchor Y offset of the kernel origin frame of reference w.r.t the
     *                 source pixel.
     * @param nDivisor The factor by which the convolved summation from the Filter
     *                 operation should be divided.  If equal to the sum of
     *                 coefficients, this will keep the maximum result value within
     *                 full scale.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterColumn_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor)
    {
        return checkResult(nppiFilterColumn_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, pKernel, nMaskSize, nAnchor, nDivisor));
    }
    private static native int nppiFilterColumn_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor);


    /**
     * <pre>
     * 8-bit unsigned 1D (row) image convolution.
     *
     * Apply general linear Row convolution filter, with rescaling, in a 1D mask
     * region around each source pixel for 1-channel 8 bit/pixel images.  
     * Result pixel is equal to the sum of the products between the kernel
     * coefficients (pKernel array) and corresponding neighboring row pixel values
     * in the source image defined by iKernelDim and iAnchorX, divided by iDivisor. 
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param pKernel Pointer to the start address of the kernel coefficient array.
     *                Coefficients are expected to be stored in reverse order.  
     * @param nMaskSize Length of the linear kernel array.
     * @param nAnchor X offset of the kernel origin frame of reference w.r.t the
     *                 source pixel.
     * @param nDivisor The factor by which the convolved summation from the Filter
     *                 operation should be divided.  If equal to the sum of
     *                 coefficients, this will keep the maximum result value within
     *                 full scale.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterRow_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor)
    {
        return checkResult(nppiFilterRow_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, pKernel, nMaskSize, nAnchor, nDivisor));
    }
    private static native int nppiFilterRow_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned 1D (row) image convolution.
     *
     * Apply general linear Row convolution filter, with rescaling, in a 1D mask
     * region around each source pixel for 1-channel 8 bit/pixel images.  
     * Result pixel is equal to the sum of the products between the kernel
     * coefficients (pKernel array) and corresponding neighboring row pixel values
     * in the source image defined by iKernelDim and iAnchorX, divided by iDivisor. 
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param pKernel Pointer to the start address of the kernel coefficient array.
     *                Coefficients are expected to be stored in reverse order.  
     * @param nMaskSize Length of the linear kernel array.
     * @param nAnchor X offset of the kernel origin frame of reference w.r.t the
     *                 source pixel.
     * @param nDivisor The factor by which the convolved summation from the Filter
     *                 operation should be divided.  If equal to the sum of
     *                 coefficients, this will keep the maximum result value within
     *                 full scale.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterRow_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor)
    {
        return checkResult(nppiFilterRow_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, pKernel, nMaskSize, nAnchor, nDivisor));
    }
    private static native int nppiFilterRow_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        TypedPointer<Npp32s> pKernel, 
        int nMaskSize, 
        int nAnchor, 
        int nDivisor);


    ///@}
    /** @name 1D Window Sum
     *  1D mask Window Sum for 8 bit images.
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned 1D (column) sum to 32f.
     *
     * Apply Column Window Summation filter over a 1D mask region around each
     * source pixel for 1-channel 8 bit/pixel input images with 32-bit floating point
     * output.  
     * Result 32-bit floating point pixel is equal to the sum of the corresponding and
     * neighboring column pixel values in a mask region of the source image defined by
     * nMaskSize and nAnchor. 
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param nMaskSize Length of the linear kernel array.
     * @param nAnchor Y offset of the kernel origin frame of reference w.r.t the
     *        source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSumWindowColumn_8u32f_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int nMaskSize, 
        int nAnchor)
    {
        return checkResult(nppiSumWindowColumn_8u32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, nMaskSize, nAnchor));
    }
    private static native int nppiSumWindowColumn_8u32f_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int nMaskSize, 
        int nAnchor);


    /**
     * <pre>
     * 8-bit unsigned 1D (row) sum to 32f.
     *
     * Apply Row Window Summation filter over a 1D mask region around each source
     * pixel for 1-channel 8-bit pixel input images with 32-bit floating point output.  
     * Result 32-bit floating point pixel is equal to the sum of the corresponding and
     * neighboring row pixel values in a mask region of the source image defined
     * by iKernelDim and iAnchorX. 
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param nMaskSize Length of the linear kernel array.
     * @param nAnchor X offset of the kernel origin frame of reference w.r.t the
     *        source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiSumWindowRow_8u32f_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int nMaskSize, 
        int nAnchor)
    {
        return checkResult(nppiSumWindowRow_8u32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, nMaskSize, nAnchor));
    }
    private static native int nppiSumWindowRow_8u32f_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int nMaskSize, 
        int nAnchor);


    ///@}
    /** @name Convolution (2D Masks)
     * General purpose 2D convolution filters.
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned convolution filter.
     * 
     * Pixels under the mask are multiplied by the respective weights in the mask
     * and the results are summed. Before writing the result pixel the sum is scaled
     * back via division by nDivisor.
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pKernel Pointer to the start address of the kernel coefficient array.
     *        Coeffcients are expected to be stored in reverse order.
     * @param oKernelSize Width and Height of the rectangular kernel.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference
     *        w.r.t the source pixel.
     * @param nDivisor The factor by which the convolved summation from the Filter
     *        operation should be divided.  If equal to the sum of coefficients,
     *        this will keep the maximum result value within full scale.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilter_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pKernel, 
        NppiSize oKernelSize, 
        NppiPoint oAnchor, 
        int nDivisor)
    {
        return checkResult(nppiFilter_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pKernel, oKernelSize, oAnchor, nDivisor));
    }
    private static native int nppiFilter_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pKernel, 
        NppiSize oKernelSize, 
        NppiPoint oAnchor, 
        int nDivisor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned convolution filter.
     * 
     * Pixels under the mask are multiplied by the respective weights in the mask
     * and the results are summed. Before writing the result pixel the sum is scaled
     * back via division by nDivisor.
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pKernel Pointer to the start address of the kernel coefficient array.
     *        Coeffcients are expected to be stored in reverse order.
     * @param oKernelSize Width and Height of the rectangular kernel.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference
     *        w.r.t the source pixel.
     * @param nDivisor The factor by which the convolved summation from the Filter
     *        operation should be divided.  If equal to the sum of coefficients,
     *        this will keep the maximum result value within full scale.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilter_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pKernel, 
        NppiSize oKernelSize, 
        NppiPoint oAnchor, 
        int nDivisor)
    {
        return checkResult(nppiFilter_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pKernel, oKernelSize, oAnchor, nDivisor));
    }
    private static native int nppiFilter_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pKernel, 
        NppiSize oKernelSize, 
        NppiPoint oAnchor, 
        int nDivisor);


    ///@}
    /** @name 2D Linear Fixed Filters
     *  2D linear fixed filters for 8 bit images.
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned box filter.
     *
     * Computes the average pixel values of the pixels under a rectangular mask.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Avg operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference w.r.t
     *        the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterBox_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return checkResult(nppiFilterBox_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterBox_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned box filter.
     *
     * Computes the average pixel values of the pixels under a rectangular mask.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Avg operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference w.r.t
     *        the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterBox_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return checkResult(nppiFilterBox_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterBox_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    ///@}
    /** @name Image Rank Filters
     *  Min, Median, and Max image filters.
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned maximum filter.
     *
     * Result pixel value is the maximum of pixel values under the rectangular
     * mask region.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Max operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterMax_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return checkResult(nppiFilterMax_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterMax_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned maximum filter.
     *
     * Result pixel value is the maximum of pixel values under the rectangular
     * mask region.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Max operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterMax_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return checkResult(nppiFilterMax_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterMax_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 8-bit unsigned minimum filter.
     *
     * Result pixel value is the minimum of pixel values under the rectangular
     * mask region.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Max operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterMin_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return checkResult(nppiFilterMin_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterMin_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned minimum filter.
     *
     * Result pixel value is the minimum of pixel values under the rectangular
     * mask region.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param oMaskSize Width and Height of the neighborhood region for the local
     *        Max operation.
     * @param oAnchor X and Y offsets of the kernel origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiFilterMin_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return checkResult(nppiFilterMin_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, oMaskSize, oAnchor));
    }
    private static native int nppiFilterMin_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    ///@}
    ///@} image_filtering_functions
    /**
     * <pre>
     * @defgroup image_morphological_operations Morphological Operations
     *
     * Morphological image operations.
     *
     *
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned image dilation.
     * 
     * Dilation computes the output pixel as the maximum pixel value of the pixels
     * under the mask. Pixels who's corresponding mask values are zero to not 
     * participate in the maximum search.
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the start address of the mask array
     * @param oMaskSize Width and Height mask array.
     * @param oAnchor X and Y offsets of the mask origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDilate_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return checkResult(nppiDilate_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, oMaskSize, oAnchor));
    }
    private static native int nppiDilate_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image dilation.
     * 
     * Dilation computes the output pixel as the maximum pixel value of the pixels
     * under the mask. Pixels who's corresponding mask values are zero to not 
     * participate in the maximum search.
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the start address of the mask array
     * @param oMaskSize Width and Height mask array.
     * @param oAnchor X and Y offsets of the mask origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiDilate_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return checkResult(nppiDilate_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, oMaskSize, oAnchor));
    }
    private static native int nppiDilate_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 8-bit unsigned image erosion.
     * 
     * Erosion computes the output pixel as the minimum pixel value of the pixels
     * under the mask. Pixels who's corresponding mask values are zero to not 
     * participate in the maximum search.
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the start address of the mask array
     * @param oMaskSize Width and Height mask array.
     * @param oAnchor X and Y offsets of the mask origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiErode_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return checkResult(nppiErode_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, oMaskSize, oAnchor));
    }
    private static native int nppiErode_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image erosion.
     * 
     * Erosion computes the output pixel as the minimum pixel value of the pixels
     * under the mask. Pixels who's corresponding mask values are zero to not 
     * participate in the maximum search.
     *
     * @param pSrc  \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pMask Pointer to the start address of the mask array
     * @param oMaskSize Width and Height mask array.
     * @param oAnchor X and Y offsets of the mask origin frame of reference
     *        w.r.t the source pixel.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiErode_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor)
    {
        return checkResult(nppiErode_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pMask, oMaskSize, oAnchor));
    }
    private static native int nppiErode_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp8u> pMask, 
        NppiSize oMaskSize, 
        NppiPoint oAnchor);


    ///@} image_morphological_operations
    /**
     * <pre>
     * @defgroup image_linear_transforms Image Linear Transforms
     *
     * Linear image transformations.
     *
     *
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * 32-bit floating point complex to 32-bit floating point magnitude.
     * 
     * Converts complex-number pixel image to single channel image computing
     * the result pixels as the magnitude of the complex values.
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMagnitude_32fc32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMagnitude_32fc32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMagnitude_32fc32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 32-bit floating point complex to 32-bit floating point squared magnitude.
     * 
     * Converts complex-number pixel image to single channel image computing
     * the result pixels as the squared magnitude of the complex values.
     * 
     * The squared magnitude is an itermediate result of magnitude computation and
     * can thus be computed faster than actual magnitude. If magnitudes are required
     * for sorting/comparing only, using this function instead of nppiMagnitude_32fc32f_C1R
     * can be a worthwhile performance optimization.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiMagnitudeSqr_32fc32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiMagnitudeSqr_32fc32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiMagnitudeSqr_32fc32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    ///@} image_linear_transforms
    /**
     * <pre>
     * @defgroup image_compression Compression
     *
     * Image compression primitives.
     *
     * The JPEG standard defines a flow of level shift, DCT and quantization for
     * forward JPEG transform and inverse level shift, IDCT and de-quantization
     * for inverse JPEG transform. This group has the functions for both forward
     * and inverse functions. 
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * Apply quality factor to raw 8-bit quantization table.
     *
     * This is effectively and in-place method that modifies a given raw
     * quantization table based on a quality factor.
     * Note that this method is a host method and that the pointer to the
     * raw quantization table is a host pointer.
     *
     * @param hpQuantRawTable Raw quantization table.
     * @param nQualityFactor Quality factor for the table. Range is [1:100].
     * @return
     *  Error code:
     *      #NPP_NULL_POINTER_ERROR is returned if hpQuantRawTable is 0.
     * </pre>
     */
    public static int nppiQuantFwdRawTableInit_JPEG_8u(
        TypedPointer<Npp8u> hpQuantRawTable, 
        int nQualityFactor)
    {
        return checkResult(nppiQuantFwdRawTableInit_JPEG_8uNative(hpQuantRawTable, nQualityFactor));
    }
    private static native int nppiQuantFwdRawTableInit_JPEG_8uNative(
        TypedPointer<Npp8u> hpQuantRawTable, 
        int nQualityFactor);


    /**
     * <pre>
     * Initializes a quantization table for nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1R().
     *    The method creates a 16-bit version of the raw table and converts the 
     * data order from zigzag layout to original row-order layout since raw
     * quantization tables are typically stored in zigzag format.
     *
     * This method is a host method. It consumes and produces host data. I.e. the pointers
     * passed to this function must be host pointers. The resulting table needs to be
     * transferred to device memory in order to be used with nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1R()
     * function.
     *
     * @param hpQuantRawTable Host pointer to raw quantization table as returned by 
     *      nppiQuantFwdRawTableInit_JPEG_8u(). The raw quantization table is assumed to be in
     *      zigzag order.
     * @param hpQuantFwdRawTable Forward quantization table for use with nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1R().
     * @return
     *  Error code:
     *      #NPP_NULL_POINTER_ERROR pQuantRawTable is 0.
     * </pre>
     */
    public static int nppiQuantFwdTableInit_JPEG_8u16u(
        TypedPointer<Npp8u> hpQuantRawTable, 
        TypedPointer<Npp16u> hpQuantFwdRawTable)
    {
        return checkResult(nppiQuantFwdTableInit_JPEG_8u16uNative(hpQuantRawTable, hpQuantFwdRawTable));
    }
    private static native int nppiQuantFwdTableInit_JPEG_8u16uNative(
        TypedPointer<Npp8u> hpQuantRawTable, 
        TypedPointer<Npp16u> hpQuantFwdRawTable);


    /**
     * <pre>
     * Initializes a quantization table for nppiDCTQuantInv8x8LS_JPEG_16s8u_C1R().
     *      The nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1R() method uses a quantization table
     * in a 16-bit format allowing for faster processing. In addition it converts the 
     * data order from zigzag layout to original row-order layout. Typically raw
     * quantization tables are stored in zigzag format.
     *
     * This method is a host method and consumes and produces host data. I.e. the pointers
     * passed to this function must be host pointers. The resulting table needs to be
     * transferred to device memory in order to be used with nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1R()
     * function.
     *
     * @param hpQuantRawTable Raw quantization table.
     * @param hpQuantFwdRawTable Inverse quantization table.
     * @return
     *  #NPP_NULL_POINTER_ERROR pQuantRawTable or pQuantFwdRawTable is0.
     * </pre>
     */
    public static int nppiQuantInvTableInit_JPEG_8u16u(
        TypedPointer<Npp8u> hpQuantRawTable, 
        TypedPointer<Npp16u> hpQuantFwdRawTable)
    {
        return checkResult(nppiQuantInvTableInit_JPEG_8u16uNative(hpQuantRawTable, hpQuantFwdRawTable));
    }
    private static native int nppiQuantInvTableInit_JPEG_8u16uNative(
        TypedPointer<Npp8u> hpQuantRawTable, 
        TypedPointer<Npp16u> hpQuantFwdRawTable);


    /**
     * <pre>
     * Forward DCT, quantization and level shift part of the JPEG encoding.
     * Input is expected in 8x8 macro blocks and output is expected to be in 64x1
     * macro blocks.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pQuantFwdTable Forward quantization tables for JPEG encoding created
     *          using nppiQuantInvTableInit_JPEG_8u16u().
     * @param oSizeROI \ref roi_specification.
     * @return
     *  Error codes:
     *         - #NPP_SIZE_ERROR For negative input height/width or not a multiple of
     *           8 width/height.
     *         - #NPP_STEP_ERROR If input image width is not multiple of 8 or does not
     *           match ROI.
     *         - #NPP_NULL_POINTER_ERROR If the destination pointer is 0.
     * </pre>
     */
    public static int nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        TypedPointer<Npp16u> pQuantFwdTable, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, pQuantFwdTable, oSizeROI));
    }
    private static native int nppiDCTQuantFwd8x8LS_JPEG_8u16s_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16s> pDst, 
        int nDstStep, 
        TypedPointer<Npp16u> pQuantFwdTable, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * Inverse DCT, de-quantization and level shift part of the JPEG decoding.
     * Input is expected in 64x1 macro blocks and output is expected to be in 8x8
     * macro blocks.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param pQuantInvTable Inverse quantization tables for JPEG decoding created
     *           using nppiQuantInvTableInit_JPEG_8u16u().
     * @param oSizeROI \ref roi_specification.
     * @return
     *  Error codes:
     *         - #NPP_SIZE_ERROR For negative input height/width or not a multiple of
     *           8 width/height.
     *         - #NPP_STEP_ERROR If input image width is not multiple of 8 or does not
     *           match ROI.
     *         - #NPP_NULL_POINTER_ERROR If the destination pointer is 0.
     * </pre>
     */
    public static int nppiDCTQuantInv8x8LS_JPEG_16s8u_C1R(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        TypedPointer<Npp16u> pQuantInvTable, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiDCTQuantInv8x8LS_JPEG_16s8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, pQuantInvTable, oSizeROI));
    }
    private static native int nppiDCTQuantInv8x8LS_JPEG_16s8u_C1RNative(
        TypedPointer<Npp16s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        TypedPointer<Npp16u> pQuantInvTable, 
        NppiSize oSizeROI);


    ///@} image_compression
    /**
     * <pre>
     * @defgroup image_geometric_transforms Geometric Transforms
     *
     * Routines manipulating an image's geometry.
     *
     * </pre>
     */
    ///@{
    /** @name Resize
     *  Resizes 8 bit images. Handles C1 and C4 images.
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned image resize.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstROISize Size in pixels of the destination image
     * @param xFactor Factors by which x dimension is changed 
     * @param yFactor Factors by which y dimension is changed 
     * @param eInterpolation The type of eInterpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR indicates an error condition if
     *           srcROIRect has no intersection with the source image.
     *         - #NPP_RESIZE_NO_OPERATION_ERROR if either destination ROI width or
     *           height is less than 1 pixel.
     *         - #NPP_RESIZE_FACTOR_ERROR Indicates an error condition if either xFactor or
     *           yFactor is less than or equal to zero.
     *         - #NPP_INTERPOLATION_ERROR if eInterpolation has an illegal value.
     * </pre>
     */
    public static int nppiResize_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize dstROISize, 
        double xFactor, 
        double yFactor, 
        int eInterpolation)
    {
        return checkResult(nppiResize_8u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, dstROISize, xFactor, yFactor, eInterpolation));
    }
    private static native int nppiResize_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize dstROISize, 
        double xFactor, 
        double yFactor, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image resize.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstROISize Size in pixels of the destination image
     * @param xFactor Factors by which x dimension is changed 
     * @param yFactor Factors by which y dimension is changed 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR indicates an error condition if
     *           srcROIRect has no intersection with the source image.
     *         - #NPP_RESIZE_NO_OPERATION_ERROR if either destination ROI width or
     *           height is less than 1 pixel.
     *         - #NPP_RESIZE_FACTOR_ERROR Indicates an error condition if either xFactor or
     *           yFactor is less than or equal to zero.
     *         - #NPP_INTERPOLATION_ERROR if eInterpolation has an illegal value.
     * </pre>
     */
    public static int nppiResize_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize dstROISize, 
        double xFactor, 
        double yFactor, 
        int eInterpolation)
    {
        return checkResult(nppiResize_8u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, dstROISize, xFactor, yFactor, eInterpolation));
    }
    private static native int nppiResize_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize dstROISize, 
        double xFactor, 
        double yFactor, 
        int eInterpolation);


    ///@}
    /**
     * <pre>
     * @name Rotate
     *  Rotates an image around the origin (0,0) and then shifts it.
     *
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * Compute shape of rotated image.
     * 
     * @param oSrcROI Region-of-interest of the source image.
     * @param aQuad Array of 2D points. These points are the locations of the corners
     *      of the rotated ROI. 
     * @param nAngle The rotation nAngle.
     * @param nShiftX Post-rotation shift in x-direction
     * @param nShiftY Post-rotation shift in y-direction
     * @return
     *  \ref roi_error_codes.
     * </pre>
     */
    public static int nppiGetRotateQuad(
        NppiRect oSrcROI, 
        double[][] aQuad, 
        double nAngle, 
        double nShiftX, 
        double nShiftY)
    {
        return checkResult(nppiGetRotateQuadNative(oSrcROI, aQuad, nAngle, nShiftX, nShiftY));
    }
    private static native int nppiGetRotateQuadNative(
        NppiRect oSrcROI, 
        double[][] aQuad, 
        double nAngle, 
        double nShiftX, 
        double nShiftY);


    /**
     * <pre>
     * Compute bounding-box of rotated image.
     * @param oSrcROI Region-of-interest of the source image.
     * @param aBoundingBox Two 2D points representing the bounding-box of the rotated image. All four points
     *      from nppiGetRotateQuad are contained inside the axis-aligned rectangle spanned by the the two
     *      points of this bounding box.
     * @param nAngle The rotation angle.
     * @param nShiftX Post-rotation shift in x-direction.
     * @param nShiftY Post-rotation shift in y-direction.
     *
     * @return
     *  \ref roi_error_codes.
     * </pre>
     */
    public static int nppiGetRotateBound(
        NppiRect oSrcROI, 
        double[][] aBoundingBox, 
        double nAngle, 
        double nShiftX, 
        double nShiftY)
    {
        return checkResult(nppiGetRotateBoundNative(oSrcROI, aBoundingBox, nAngle, nShiftX, nShiftY));
    }
    private static native int nppiGetRotateBoundNative(
        NppiRect oSrcROI, 
        double[][] aBoundingBox, 
        double nAngle, 
        double nShiftX, 
        double nShiftY);


    /**
     * <pre>
     * 8-bit unsigned image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRotate_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_8u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 3 channel 8-bit unsigned image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_8u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_8u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image rotate ignoring alpha channel.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 16-bit unsigned image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_16u_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 3 channel 16-bit unsigned image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_16u_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_16u_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image rotate ignoring alpha channel.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 32-bit float image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_32f_C1RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 3 channel 32-bit float image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_32f_C3RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 32-bit float image rotate.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_32f_C4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    /**
     * <pre>
     * 4 channel 32-bit float image rotate ignoring alpha channel.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param oSrcSize Size in pixels of the source image
     * @param oSrcROI Region of interest in the source image.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oDstROI Region of interest in the destination image.
     * @param nAngle The angle of rotation in degrees.
     * @param nShiftX Shift along horizontal axis 
     * @param nShiftY Shift along vertical axis 
     * @param eInterpolation The type of interpolation to perform resampling
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes, \ref rotate_error_codes
     * </pre>
     */
    public static int nppiRotate_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation)
    {
        return checkResult(nppiRotate_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, oSrcROI, pDst, nDstStep, oDstROI, nAngle, nShiftX, nShiftY, eInterpolation));
    }
    private static native int nppiRotate_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect oSrcROI, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect oDstROI, 
        double nAngle, 
        double nShiftX, 
        double nShiftY, 
        int eInterpolation);


    ///@}
    /** @name Mirror
     *  Mirrors images horizontally, vertically and diagonally.
     */
    ///@{
    /**
     * <pre>
     * 8-bit unsigned image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 3 channel 8-bit unsigned image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_8u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 8-bit unsigned image mirror not affecting alpha.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 16-bit unsigned image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_16u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 3 channel 16-bit unsigned image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_16u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_16u_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 16-bit unsigned image mirror not affecting alpha.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_16u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 32-bit image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_32s_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 3 channel 32-bit image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_32s_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 32-bit image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_32s_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 32-bit image mirror not affecting alpha.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_32s_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 32-bit float image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_32f_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 3 channel 32-bit float image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_32f_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 32-bit float image mirror.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_32f_C4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    /**
     * <pre>
     * 4 channel 32-bit float image mirror not affecting alpha.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep Distance in bytes between starts of consecutive lines of the
     *        destination image.
     * @param oROI \ref roi_specification.
     * @param flip Specifies the axis about which the image is to be mirrored.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_MIRROR_FLIP_ERR if flip has an illegal value.
     * </pre>
     */
    public static int nppiMirror_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip)
    {
        return checkResult(nppiMirror_32f_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oROI, flip));
    }
    private static native int nppiMirror_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiSize oROI, 
        int flip);


    ///@}
    /**
     * <pre>
     * @name Affine warping, affine transform calculation
     * Affine warping of an image is the transform of image pixel positions,
     * defined by the following formulas:
     * \f[
     * X_{new} = C_{00} * x + C_{01} * y + C_{02} \qquad
     * Y_{new} = C_{10} * x + C_{11} * y + C_{12} \qquad
     * C = \left[ \matrix{C_{00} & C_{01} & C_{02} \cr C_{10} & C_{11} & C_{12} } \right]
     * \f]
     * That is, any pixel with coordinates 
     * \f$(X_{new},Y_{new})\f$ in the transformed image is sourced from 
     * coordinates \f$(x,y)\f$ in the original image. The mapping \f$C\f$ is completely
     * specified by 6 values
     * \f$C_{ij}, i=\overline{0,1}, j=\overline{0,2}\f$.
     * The transform maps parallel lines to parallel
     * lines and preserves ratios of distances of points to lines.
     * Implementation specific properties are
     * discussed in each function's documentation.
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * Calculates affine transform coefficients given source rectangular ROI and
     * its destination quadrangle projection
     *
     * @param srcRoi Source ROI
     * @param quad Destination quadrangle
     * @param coeffs Affine transform coefficients
     * @return
     *  Error codes:
     *         - #NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *           has zero or negative value
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_AFFINE_QUAD_INCORRECT_WARNING Indicates a warning when quad
     *           does not conform to the transform properties. Fourth vertex is
     *           ignored, internally computed coordinates are used instead
     * </pre>
     */
    public static int nppiGetAffineTransform(
        NppiRect srcRoi, 
        double[][] quad, 
        double[][] coeffs)
    {
        return checkResult(nppiGetAffineTransformNative(srcRoi, quad, coeffs));
    }
    private static native int nppiGetAffineTransformNative(
        NppiRect srcRoi, 
        double[][] quad, 
        double[][] coeffs);


    /**
     * <pre>
     * Calculates affine transform projection of given source rectangular ROI
     *
     * @param srcRoi Source ROI
     * @param quad Destination quadrangle
     * @param coeffs Affine transform coefficients
     * @return
     *  Error codes:
     *         - #NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *           has zero or negative value
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     * </pre>
     */
    public static int nppiGetAffineQuad(
        NppiRect srcRoi, 
        double[][] quad, 
        double[][] coeffs)
    {
        return checkResult(nppiGetAffineQuadNative(srcRoi, quad, coeffs));
    }
    private static native int nppiGetAffineQuadNative(
        NppiRect srcRoi, 
        double[][] quad, 
        double[][] coeffs);


    /**
     * <pre>
     * Calculates bounding box of the affine transform projection of the given
     * source rectangular ROI
     *
     * @param srcRoi Source ROI
     * @param bound Bounding box of the transformed source ROI
     * @param coeffs Affine transform coefficients
     * @return
     *  Error codes:
     *         - #NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *           has zero or negative value
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     * </pre>
     */
    public static int nppiGetAffineBound(
        NppiRect srcRoi, 
        double[][] bound, 
        double[][] coeffs)
    {
        return checkResult(nppiGetAffineBoundNative(srcRoi, bound, coeffs));
    }
    private static native int nppiGetAffineBoundNative(
        NppiRect srcRoi, 
        double[][] bound, 
        double[][] coeffs);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, single channel). This
     * function operates using given transform coefficients that can be obtained
     * by using nppiGetAffineTransform function or set explicitly. The function
     * operates on source and destination regions of interest. The affine warp
     * function transforms the source image pixel coordinates \f$(x,y)\f$ according
     * to the following formulas:
     * \f[
     * X_{new} = C_{00} * x + C_{01} * y + C_{02} \qquad
     * Y_{new} = C_{10} * x + C_{11} * y + C_{12} \qquad
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetAffineQuad and nppiGetAffineBound can help with 
     * destination ROI specification.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The fast
     * method is about 4 times faster than its accurate variant,
     * but does not perform memory access checks and requires the destination ROI
     * to be 64 bytes aligned. Hence any destination ROI is 
     * chunked into 3 vertical stripes: the first and the third are processed by
     * accurate kernels and the central one is processed by the
     * fast one.
     * In order to get the maximum available speed of execution, the projection of
     * destination ROI onto image addresses must be 64 bytes
     * aligned. This is always true if the values 
     * <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt> 
     * are multiples of 64. Another rule of thumb is to specify destination ROI in
     * such way that left and right sides of the projected 
     * image are separated from the ROI by at least 63 bytes from each side.
     * However, this requires the whole ROI to be part of allocated memory. In case
     * when the conditions above are not satisfied, the function may decrease in
     * speed slightly and will return NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           interpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     * </pre>
     */
    public static int nppiWarpAffine_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_8u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, three channels).
     * @see nppiWarpAffine_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffine_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_8u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, four channels).
     * @see nppiWarpAffine_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffine_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_8u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, four channels RGBA).
     * @see nppiWarpAffine_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffine_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, three planes).
     * @see nppiWarpAffine_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffine_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_8u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, four planes).
     * @see nppiWarpAffine_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffine_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_8u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (8bit unsigned integer, single channel).
     * This function operates using given transform coefficients that can be
     * obtained by using nppiGetAffineTransform function or set explicitly. Thus
     * there is no need to invert coefficients in your application before calling
     * WarpAffineBack. The function operates on source and destination regions of
     * interest.
     * The affine warp function transforms the source image pixel coordinates
     * \f$(x,y)\f$ according to the following formulas:
     * \f[
     * C_{00} * X_{new} + C_{01} * Y_{new} + C_{02} = x  \qquad
     * C_{10} * X_{new} + C_{11} * Y_{new} + C_{12} = y
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetAffineQuad and nppiGetAffineBound can help with
     * destination ROI specification.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The fast
     * method is about 4 times faster than its accurate variant,
     * but doesn't perform memory access checks and requires the destination ROI
     * to be 64 bytes aligned. Hence any destination ROI is 
     * chunked into 3 vertical stripes: the first and the third are processed by
     * accurate kernels and the central one is processed by the fast one.
     * In order to get the maximum available speed of execution, the projection of
     * destination ROI onto image addresses must be 64 bytes aligned. This is
     * always true if the values 
     * <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt> 
     * are multiples of 64. Another rule of thumb is to specify destination ROI in
     * such way that left and right sides of the projected image are separated from
     * the ROI by at least 63 bytes from each side. However, this requires the
     * whole ROI to be part of allocated memory. In case when the conditions above
     * are not satisfied, the function may decrease in speed slightly and will
     * return NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           interpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     * </pre>
     */
    public static int nppiWarpAffineBack_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_8u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (8bit unsigned integer, three channels).
     * @see nppiWarpAffineBack_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_8u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (8bit unsigned integer, four channels).
     * @see nppiWarpAffineBack_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_8u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (8bit unsigned integer, four channels RGBA).
     * @see nppiWarpAffineBack_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (8bit unsigned integer, three planes).
     * @see nppiWarpAffineBack_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_8u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (8bit unsigned integer, four planes).
     * @see nppiWarpAffineBack_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_8u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, single channel). This
     * function performs affine warping of a the specified quadrangle in the
     * source image to the specified quadrangle in the destination image. The
     * function nppiWarpAffineQuad uses the same formulas for pixel mapping as in
     * nppiWarpAffine function. The transform coefficients are computed internally.
     * The transformed part of the source image is resampled using the specified
     * eInterpolation method and written to the destination ROI.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The fast
     * method is about 4 times faster than its accurate variant, but does not
     * perform memory access checks and requires the destination ROI to be 64 bytes
     * aligned. Hence any destination ROI is chunked into 3 vertical stripes: the
     * first and the third are processed by accurate kernels and the central one is
     * processed by the fast one.
     * In order to get the maximum available speed of execution, the projection of
     * destination ROI onto image addresses must be 64 bytes aligned. This is
     * always true if the values <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt> 
     * are multiples of 64. Another rule of thumb is to specify destination ROI in
     * such way that left and right sides of the projected image are separated from
     * the ROI by at least 63 bytes from each side. However, this requires the
     * whole ROI to be part of allocated memory. In case when the conditions above
     * are not satisfied, the function may decrease in speed slightly and will
     * return NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param srcQuad Source quadrangle
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param dstQuad Destination quadrangle
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     *         ignored, internally computed coordinates are used instead
     * </pre>
     */
    public static int nppiWarpAffineQuad_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_8u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, three channels).
     * @see nppiWarpAffineQuad_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_8u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, four channels).
     * @see nppiWarpAffineQuad_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_8u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, four channels RGBA).
     * @see nppiWarpAffineQuad_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, three planes).
     * @see nppiWarpAffineQuad_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_8u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (8bit unsigned integer, four planes).
     * @see nppiWarpAffineQuad_8u_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_8u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, single channel). This
     * function operates using given transform coefficients that can be obtained by
     * using nppiGetAffineTransform function or set explicitly. The function
     * operates on source and destination regions of interest. The affine warp
     * function transforms the source image pixel coordinates \f$(x,y)\f$
     * according to the following formulas:
     * \f[
     * X_{new} = C_{00} * x + C_{01} * y + C_{02} \qquad
     * Y_{new} = C_{10} * x + C_{11} * y + C_{12} \qquad
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetAffineQuad and nppiGetAffineBound can help with
     * destination ROI specification.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The fast
     * method is about 4 times faster than its accurate variant, but does not
     * perform memory access checks and requires the destination ROI to be 64 bytes
     * aligned. Hence any destination ROI is chunked into 3 vertical stripes: the
     * first and the third are processed by accurate kernels and the central one is processed by the
     * fast one.
     * In order to get the maximum available speed of execution, the projection of
     * destination ROI onto image addresses must be 64 bytes aligned. This is
     * always true if the values <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt>  are multiples of
     * 64. Another rule of thumb is to specify destination ROI in such way that
     * left and right sides of the projected image are separated from the ROI by at
     * least 63 bytes from each side. However, this requires the whole ROI to be
     * part of allocated memory. In case when the conditions above are not
     * satisfied, the function may decrease in speed slightly and will return 
     * NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     * </pre>
     */
    public static int nppiWarpAffine_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_16u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, three channels)
     * @see nppiWarpAffine_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffine_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_16u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, four channels)
     * @see nppiWarpAffine_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffine_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_16u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, four channels RGBA)
     * @see nppiWarpAffine_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffine_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, three planes)
     * @see nppiWarpAffine_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffine_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_16u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, four planes)
     * @see nppiWarpAffine_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffine_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_16u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (16bit unsigned integer, single 
     * channel). This function operates using given transform coefficients that 
     * can be obtained by using nppiGetAffineTransform function or set explicitly.
     * Thus there is no need to invert coefficients in your application 
     * before calling WarpAffineBack. The function operates on source and
     * destination regions of interest.
     * The affine warp function transforms the source image pixel coordinates
     * \f$(x,y)\f$ according to the following formulas:
     * \f[
     * C_{00} * X_{new} + C_{01} * Y_{new} + C_{02} = x  \qquad
     * C_{10} * X_{new} + C_{11} * Y_{new} + C_{12} = y
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetAffineQuad and nppiGetAffineBound can help with
     * destination ROI specification.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The fast
     * method is about 4 times faster than its accurate variant,
     * but doesn't perform memory access checks and requires the destination ROI
     * to be 64 bytes aligned. Hence any destination ROI is 
     * chunked into 3 vertical stripes: the first and the third are processed by
     * accurate kernels and the central one is processed by the
     * fast one.
     * In order to get the maximum available speed of execution, the projection of
     * destination ROI onto image addresses must be 64 bytes
     * aligned. This is always true if the values 
     * <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt> 
     * are multiples of 64. Another rule of thumb is to specify destination ROI in
     * such way that left and right sides of the projected 
     * image are separated from the ROI by at least 63 bytes from each side.
     * However, this requires the whole ROI to be part of allocated 
     * memory. In case when the conditions above are not satisfied, the function may
     * decrease in speed slightly and will return 
     * NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_16u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (16bit unsigned integer, three channels)
     * @see nppiWarpAffineBack_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_16u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (16bit unsigned integer, four channels)
     * @see nppiWarpAffineBack_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_16u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (16bit unsigned integer, four channels
     * RGBA)
     * @see nppiWarpAffineBack_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (16bit unsigned integer, three planes)
     * @see nppiWarpAffineBack_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_16u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (16bit unsigned integer, four planes)
     * @see nppiWarpAffineBack_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_16u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, single channel). This
     * function performs affine warping of a the specified
     * quadrangle in the source image to the specified quadrangle in the
     * destination image. The function nppiWarpAffineQuad uses the same
     * formulas for pixel mapping as in nppiWarpAffine function. The transform
     * coefficients are computed internally.
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The fast
     * method is about 4 times faster than its accurate variant,
     * but doesn't perform memory access checks and requires the destination ROI
     * to be 64 bytes aligned. Hence any destination ROI is 
     * chunked into 3 vertical stripes: the first and the third are processed by
     * accurate kernels and the central one is processed by the
     * fast one.
     * In order to get the maximum available speed of execution, the projection of
     * destination ROI onto image addresses must be 64 bytes
     * aligned. This is always true if the values 
     * <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt> 
     * are multiples of 64. Another rule of thumb is to specify destination ROI in 
     * such way that left and right sides of the projected 
     * image are separated from the ROI by at least 63 bytes from each side.
     * However, this requires the whole ROI to be part of allocated 
     * memory. In case when the conditions above are not satisfied, the function
     * may decrease in speed slightly and will return 
     * NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param srcQuad Source quadrangle
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param dstQuad Destination quadrangle
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_16u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, three channels). 
     * @see nppiWarpAffineQuad_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_16u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, four channels). 
     * @see nppiWarpAffineQuad_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_16u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, four channels RGBA). 
     * @see nppiWarpAffineQuad_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, three planes). 
     * @see nppiWarpAffineQuad_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_16u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (16bit unsigned integer, four planes). 
     * @see nppiWarpAffineQuad_16u_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_16u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, single channel). This function
     * operates using given transform coefficients that 
     * can be obtained by using nppiGetAffineTransform function or set explicitly.
     * The function operates on source and destination regions 
     * of interest. The affine warp function transforms the source image pixel
     * coordinates \f$(x,y)\f$ according to the following formulas:
     * \f[
     * X_{new} = C_{00} * x + C_{01} * y + C_{02} \qquad
     * Y_{new} = C_{10} * x + C_{11} * y + C_{12} \qquad
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetAffineQuad and nppiGetAffineBound can help with
     * destination ROI specification.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     * </pre>
     */
    public static int nppiWarpAffine_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_32f_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, three channels).
     * @see nppiWarpAffine_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffine_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_32f_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, four channels).
     * @see nppiWarpAffine_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffine_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_32f_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, four channels RGBA).
     * @see nppiWarpAffine_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffine_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, three planes).
     * @see nppiWarpAffine_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffine_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_32f_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, four planes).
     * @see nppiWarpAffine_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffine_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_32f_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit float, single channel). This
     * function operates using given transform coefficients that 
     * can be obtained by using nppiGetAffineTransform function or set explicitly.
     * Thus there is no need to invert coefficients in your application 
     * before calling WarpAffineBack. The function operates on source and
     * destination regions of interest.
     * The affine warp function transforms the source image pixel coordinates
     * \f$(x,y)\f$ according to the following formulas:
     * \f[
     * C_{00} * X_{new} + C_{01} * Y_{new} + C_{02} = x  \qquad
     * C_{10} * X_{new} + C_{11} * Y_{new} + C_{12} = y
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetAffineQuad and nppiGetAffineBound can help with
     * destination ROI specification.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     * </pre>
     */
    public static int nppiWarpAffineBack_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32f_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit float, three channels).
     * @see nppiWarpAffineBack_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32f_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit float, four channels).
     * @see nppiWarpAffineBack_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32f_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit float, four channels RGBA).
     * @see nppiWarpAffineBack_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit float, three planes).
     * @see nppiWarpAffineBack_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32f_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit float, four planes).
     * @see nppiWarpAffineBack_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32f_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, single channel). This function
     * performs affine warping of a the specified
     * quadrangle in the source image to the specified quadrangle in the
     * destination image. The function nppiWarpAffineQuad uses the same
     * formulas for pixel mapping as in nppiWarpAffine function. The transform
     * coefficients are computed internally.
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param srcQuad Source quadrangle
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param dstQuad Destination quadrangle
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     * </pre>
     */
    public static int nppiWarpAffineQuad_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32f_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, three channels).
     * @see nppiWarpAffineQuad_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32f_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, four channels).
     * @see nppiWarpAffineQuad_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32f_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, four channels RGBA).
     * @see nppiWarpAffineQuad_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, three planes).
     * @see nppiWarpAffineQuad_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32f_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit float, four planes).
     * @see nppiWarpAffineQuad_32f_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32f_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, single channel). This
     * function operates using given transform coefficients that 
     * can be obtained by using nppiGetAffineTransform function or set explicitly.
     * The function operates on source and destination regions 
     * of interest. The affine warp function transforms the source image pixel
     * coordinates \f$(x,y)\f$ according to the following formulas:
     * \f[
     * X_{new} = C_{00} * x + C_{01} * y + C_{02} \qquad
     * Y_{new} = C_{10} * x + C_{11} * y + C_{12} \qquad
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetAffineQuad and nppiGetAffineBound can help with
     * destination ROI specification.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     * </pre>
     */
    public static int nppiWarpAffine_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_32s_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, three channels).
     * @see nppiWarpAffine_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffine_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int interpolation)
    {
        return checkResult(nppiWarpAffine_32s_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, interpolation));
    }
    private static native int nppiWarpAffine_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int interpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, four channels).
     * @see nppiWarpAffine_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffine_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_32s_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, four channels RGBA).
     * @see nppiWarpAffine_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffine_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, three planes).
     * @see nppiWarpAffine_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffine_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_32s_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, four planes).
     * @see nppiWarpAffine_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffine_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffine_32s_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffine_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit signed integer, single
     * channel). This function operates using given transform coefficients that 
     * can be obtained by using nppiGetAffineTransform function or set explicitly.
     * Thus there is no need to invert coefficients in your application 
     * before calling WarpAffineBack. The function operates on source and
     * destination regions of interest.
     * The affine warp function transforms the source image pixel coordinates
     * \f$(x,y)\f$ according to the following formulas:
     * \f[
     * C_{00} * X_{new} + C_{01} * Y_{new} + C_{02} = x  \qquad
     * C_{10} * X_{new} + C_{11} * Y_{new} + C_{12} = y
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetAffineQuad and nppiGetAffineBound can help with
     * destination ROI specification.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Affine transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     * </pre>
     */
    public static int nppiWarpAffineBack_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32s_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit signed integer, three channels).
     * @see nppiWarpAffineBack_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32s_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit signed integer, four channels).
     * @see nppiWarpAffineBack_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32s_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit signed integer, four channels RGBA).
     * @see nppiWarpAffineBack_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit signed integer, three planes).
     * @see nppiWarpAffineBack_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32s_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse affine transform of an image (32bit signed integer, four planes).
     * @see nppiWarpAffineBack_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffineBack_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineBack_32s_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpAffineBack_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, single channel). This
     * function performs affine warping of a the specified
     * quadrangle in the source image to the specified quadrangle in the
     * destination image. The function nppiWarpAffineQuad uses the same
     * formulas for pixel mapping as in nppiWarpAffine function. The transform
     * coefficients are computed internally.
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param srcQuad Source quadrangle
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param dstQuad Destination quadrangle
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     *           misalignment
     * </pre>
     */
    public static int nppiWarpAffineQuad_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32s_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, three channels).
     * @see nppiWarpAffineQuad_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32s_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, four channels).
     * @see nppiWarpAffineQuad_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32s_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, four channels RGBA).
     * @see nppiWarpAffineQuad_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, three planes).
     * @see nppiWarpAffineQuad_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32s_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Affine transform of an image (32bit signed integer, four planes).
     * @see nppiWarpAffineQuad_32s_C1R
     * </pre>
     */
    public static int nppiWarpAffineQuad_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpAffineQuad_32s_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpAffineQuad_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    ///@}
    /**
     * <pre>
     * @name Perspective warping, perspective transform calculation
     *  Perspective warping of an image is the transform of image pixel positions,
     * defined by the following formulas:
     * \f[
     * X_{new} = \frac{C_{00} * x + C_{01} * y + C_{02}}{C_{20} * x + C_{21} * y + C_{22}} \qquad
     * Y_{new} = \frac{C_{10} * x + C_{11} * y + C_{12}}{C_{20} * x + C_{21} * y + C_{22}} \qquad
     * C = \left[ \matrix{C_{00} & C_{01} & C_{02} \cr C_{10} & C_{11} & C_{12} \cr C_{20} & C_{21} & C_{22} } \right]
     * \f]
     * That is, any pixel of the transformed image with coordinates 
     * \f$(X_{new},Y_{new})\f$ has a preimage with 
     * coordinates \f$(x,y)\f$. The mapping \f$C\f$ is fully defined by 8 values
     * \f$C_{ij}, (i,j)=\overline{0,2}\f$, except of \f$C_{22}\f$, which is a
     * normalizer.
     * The transform has a property of mapping any convex quadrangle to a convex
     * quadrangle, which is used in a group of functions nppiWarpPerspectiveQuad.
     * The NPPI implementation of perspective transform has some issues which are
     * discussed in each function's documentation.
     * </pre>
     */
    ///@{
    /**
     * <pre>
     * Calculates perspective transform coefficients given source rectangular ROI
     * and its destination quadrangle projection
     *
     * @param srcRoi Source ROI
     * @param quad Destination quadrangle
     * @param coeffs Perspective transform coefficients
     * @return
     *  Error codes:
     *         - #NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *           has zero or negative value
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     * </pre>
     */
    public static int nppiGetPerspectiveTransform(
        NppiRect srcRoi, 
        double[][] quad, 
        double[][] coeffs)
    {
        return checkResult(nppiGetPerspectiveTransformNative(srcRoi, quad, coeffs));
    }
    private static native int nppiGetPerspectiveTransformNative(
        NppiRect srcRoi, 
        double[][] quad, 
        double[][] coeffs);


    /**
     * <pre>
     * Calculates perspective transform projection of given source rectangular
     * ROI
     *
     * @param srcRoi Source ROI
     * @param quad Destination quadrangle
     * @param coeffs Perspective transform coefficients
     * @return
     *  Error codes:
     *         - #NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *           has zero or negative value
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     * </pre>
     */
    public static int nppiGetPerspectiveQuad(
        NppiRect srcRoi, 
        double[][] quad, 
        double[][] coeffs)
    {
        return checkResult(nppiGetPerspectiveQuadNative(srcRoi, quad, coeffs));
    }
    private static native int nppiGetPerspectiveQuadNative(
        NppiRect srcRoi, 
        double[][] quad, 
        double[][] coeffs);


    /**
     * <pre>
     * Calculates bounding box of the perspective transform projection of the
     * given source rectangular ROI
     *
     * @param srcRoi Source ROI
     * @param bound Bounding box of the transformed source ROI
     * @param coeffs Perspective transform coefficients
     * @return
     *  Error codes:
     *         - #NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *           has zero or negative value
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     * </pre>
     */
    public static int nppiGetPerspectiveBound(
        NppiRect srcRoi, 
        double[][] bound, 
        double[][] coeffs)
    {
        return checkResult(nppiGetPerspectiveBoundNative(srcRoi, bound, coeffs));
    }
    private static native int nppiGetPerspectiveBoundNative(
        NppiRect srcRoi, 
        double[][] bound, 
        double[][] coeffs);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, single channel).
     * This function operates using given transform coefficients that 
     * can be obtained by using nppiGetPerspectiveTransform function or set
     * explicitly. The function operates on source and destination regions 
     * of interest. The perspective warp function transforms the source image
     * pixel coordinates \f$(x,y)\f$ according to the following formulas:
     * \f[
     * X_{new} = \frac{C_{00} * x + C_{01} * y + C_{02}}{C_{20} * x + C_{21} * y + C_{22}} \qquad
     * Y_{new} = \frac{C_{10} * x + C_{11} * y + C_{12}}{C_{20} * x + C_{21} * y + C_{22}}
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetPerspectiveQuad and nppiGetPerspectiveBound can help
     * with destination ROI specification.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The fast
     * method is about 4 times faster than its accurate variant,
     * but does not perform memory access checks and requires the destination ROI
     * to be 64 bytes aligned. Hence any destination ROI is 
     * chunked into 3 vertical stripes: the first and the third are processed by
     * accurate kernels and the central one is processed by the
     * fast one.
     * In order to get the maximum available speed of execution, the projection of
     * destination ROI onto image addresses must be 64 bytes
     * aligned. This is always true if the values 
     * <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt> 
     * are multiples of 64. Another rule of thumb is to specify destination ROI in
     * such way that left and right sides of the projected 
     * image are separated from the ROI by at least 63 bytes from each side.
     * However, this requires the whole ROI to be part of allocated 
     * memory. In case when the conditions above are not satisfied, the function
     * may decrease in speed slightly and will return 
     * NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspective_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_8u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, three channels).
     * @see nppiWarpPerspective_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_8u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, four channels).
     * @see nppiWarpPerspective_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_8u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, four channels RGBA).
     * @see nppiWarpPerspective_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, three planes).
     * @see nppiWarpPerspective_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_8u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, four planes).
     * @see nppiWarpPerspective_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_8u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (8bit unsigned integer, single
     * channel). This function operates using given transform coefficients that 
     * can be obtained by using nppiGetPerspectiveTransform function or set
     * explicitly. Thus there is no need to invert coefficients in your application 
     * before calling WarpPerspectiveBack. The function operates on source and
     * destination regions of interest.
     * The perspective warp function transforms the source image pixel
     * coordinates \f$(x,y)\f$ according to the following formulas:
     * \f[
     * \frac{C_{00} * X_{new} + C_{01} * Y_{new} + C_{02}}{C_{20} * X_{new} + C_{21} * Y_{new} + C_{22}} = x  \qquad
     * \frac{C_{10} * X_{new} + C_{11} * Y_{new} + C_{12}}{C_{20} * X_{new} + C_{21} * Y_{new} + C_{22}} = y
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetPerspectiveQuad and nppiGetPerspectiveBound can help
     * with destination ROI specification.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The fast
     * method is about 4 times faster than its accurate variant,
     * but does not perform memory access checks and requires the destination ROI 
     * to be 64 bytes aligned. Hence any destination ROI is 
     * chunked into 3 vertical stripes: the first and the third are processed by
     * accurate kernels and the central one is processed by the
     * fast one.
     * In order to get the maximum available speed of execution, the projection of
     * destination ROI onto image addresses must be 64 bytes
     * aligned. This is always true if the values 
     * <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt> 
     * are multiples of 64. Another rule of thumb is to specify destination ROI
     * in such way that left and right sides of the projected 
     * image are separated from the ROI by at least 63 bytes from each side.
     * However, this requires the whole ROI to be part of allocated 
     * memory. In case when the conditions above are not satisfied, the function
     * may decrease in speed slightly and will return 
     * NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN, NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_8u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (8bit unsigned integer, three channels).
     * @see nppiWarpPerspectiveBack_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_8u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (8bit unsigned integer, four channels).
     * @see nppiWarpPerspectiveBack_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_8u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (8bit unsigned integer, four channels RGBA).
     * @see nppiWarpPerspectiveBack_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (8bit unsigned integer, three planes).
     * @see nppiWarpPerspectiveBack_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_8u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (8bit unsigned integer, four planes).
     * @see nppiWarpPerspectiveBack_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_8u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, single channel).
     * This function performs perspective warping of a the specified
     * quadrangle in the source image to the specified quadrangle in the
     * destination image. The function nppiWarpPerspectiveQuad uses the same
     * formulas for pixel mapping as in nppiWarpPerspective function. The
     * transform coefficients are computed internally.
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The fast
     * method is about 4 times faster than its accurate variant,
     * but does not perform memory access checks and requires the destination ROI
     * to be 64 bytes aligned. Hence any destination ROI is 
     * chunked into 3 vertical stripes: the first and the third are processed by
     * accurate kernels and the central one is processed by the
     * fast one.
     * In order to get the maximum available speed of execution, the projection
     * of destination ROI onto image addresses must be 64 bytes
     * aligned. This is always true if the values 
     * <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt> 
     * are multiples of 64. Another rule of thumb is to specify destination ROI
     * in such way that left and right sides of the projected 
     * image are separated from the ROI by at least 63 bytes from each side.
     * However, this requires the whole ROI to be part of allocated 
     * memory. In case when the conditions above are not satisfied, the function
     * may decrease in speed slightly and will return 
     * NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param srcQuad Source quadrangle
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param dstQuad Destination quadrangle
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_8u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, three channels).
     * @see nppiWarpPerspectiveQuad_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_8u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, four channels).
     * @see nppiWarpPerspectiveQuad_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_C4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_8u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_C4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, four channels RGBA).
     * @see nppiWarpPerspectiveQuad_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_8u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, three planes).
     * @see nppiWarpPerspectiveQuad_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_8u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (8bit unsigned integer, four planes).
     * @see nppiWarpPerspectiveQuad_8u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_8u_P4R(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_8u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_8u_P4RNative(
        TypedPointer<Npp8u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, single channel).
     * This function operates using given transform coefficients that 
     * can be obtained by using nppiGetPerspectiveTransform function or set
     * explicitly. The function operates on source and destination regions 
     * of interest. The perspective warp function transforms the source image pixel
     * coordinates \f$(x,y)\f$ according to the following formulas:
     * \f[
     * X_{new} = \frac{C_{00} * x + C_{01} * y + C_{02}}{C_{20} * x + C_{21} * y + C_{22}} \qquad
     * Y_{new} = \frac{C_{10} * x + C_{11} * y + C_{12}}{C_{20} * x + C_{21} * y + C_{22}}
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetPerspectiveQuad and nppiGetPerspectiveBound can help
     * with destination ROI specification.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The
     * fast method is about 4 times faster than its accurate variant,
     * but does not perform memory access checks and requires the destination ROI
     * to be 64 bytes aligned. Hence any destination ROI is 
     * chunked into 3 vertical stripes: the first and the third are processed by
     * accurate kernels and the central one is processed by the
     * fast one.
     * In order to get the maximum available speed of execution, the projection of
     * destination ROI onto image addresses must be 64 bytes
     * aligned. This is always true if the values 
     * <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt> 
     * are multiples of 64. Another rule of thumb is to specify destination ROI in
     * such way that left and right sides of the projected 
     * image are separated from the ROI by at least 63 bytes from each side.
     * However, this requires the whole ROI to be part of allocated 
     * memory. In case when the conditions above are not satisfied, the function
     * may decrease in speed slightly and will return 
     * NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs  Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspective_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_16u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, three channels)
     * @see nppiWarpPerspective_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_16u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, four channels)
     * @see nppiWarpPerspective_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_16u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, four channels RGBA)
     * @see nppiWarpPerspective_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, three planes)
     * @see nppiWarpPerspective_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_16u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, four planes)
     * @see nppiWarpPerspective_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_16u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (16bit unsigned integer, single
     * channel). This function operates using given transform coefficients that 
     * can be obtained by using nppiGetPerspectiveTransform function or set
     * explicitly. Thus there is no need to invert coefficients in your application 
     * before calling WarpPerspectiveBack. The function operates on source and
     * destination regions of interest.
     * The perspective warp function transforms the source image pixel coordinates
     * \f$(x,y)\f$ according to the following formulas:
     * \f[
     * \frac{C_{00} * X_{new} + C_{01} * Y_{new} + C_{02}}{C_{20} * X_{new} + C_{21} * Y_{new} + C_{22}} = x  \qquad
     * \frac{C_{10} * X_{new} + C_{11} * Y_{new} + C_{12}}{C_{20} * X_{new} + C_{21} * Y_{new} + C_{22}} = y
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetPerspectiveQuad and nppiGetPerspectiveBound can help
     * with destination ROI specification.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The fast
     * method is about 4 times faster than its accurate variant,
     * but does not perform memory access checks and requires the destination ROI
     * to be 64 bytes aligned. Hence any destination ROI is 
     * chunked into 3 vertical stripes: the first and the third are processed by
     * accurate kernels and the central one is processed by the
     * fast one.
     * In order to get the maximum available speed of execution, the projection of
     * destination ROI onto image addresses must be 64 bytes
     * aligned. This is always true if the values 
     * <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt> 
     * are multiples of 64. Another rule of thumb is to specify destination ROI in
     * such way that left and right sides of the projected 
     * image are separated from the ROI by at least 63 bytes from each side.
     * However, this requires the whole ROI to be part of allocated 
     * memory. In case when the conditions above are not satisfied, the function
     * may decrease in speed slightly and will return 
     * NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_16u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (16bit unsigned integer, three channels)
     * @see nppiWarpPerspectiveBack_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_16u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (16bit unsigned integer, four channels)
     * @see nppiWarpPerspectiveBack_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_16u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (16bit unsigned integer, four channels RGBA)
     * @see nppiWarpPerspectiveBack_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (16bit unsigned integer, three planes)
     * @see nppiWarpPerspectiveBack_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_16u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (16bit unsigned integer, four planes)
     * @see nppiWarpPerspectiveBack_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_16u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, single channel).
     * This function performs perspective warping of a the specified
     * quadrangle in the source image to the specified quadrangle in the
     * destination image. The function nppiWarpPerspectiveQuad uses the same
     * formulas for pixel mapping as in nppiWarpPerspective function. The transform
     * coefficients are computed internally.
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * 
     * NPPI specific recommendation: 
     * The function operates using 2 types of kernels: fast and accurate. The fast
     * method is about 4 times faster than its accurate variant,
     * but does not perform memory access checks and requires the destination ROI to
     * be 64 bytes aligned. Hence any destination ROI is 
     * chunked into 3 vertical stripes: the first and the third are processed by
     * accurate kernels and the central one is processed by the
     * fast one.
     * In order to get the maximum available speed of execution, the projection of
     * destination ROI onto image addresses must be 64 bytes
     * aligned. This is always true if the values 
     * <tt>(int)((void *)(pDst + dstRoi.x))</tt> and 
     * <tt>(int)((void *)(pDst + dstRoi.x + dstRoi.width))</tt> 
     * are multiples of 64. Another rule of thumb is to specify destination ROI in
     * such way that left and right sides of the projected 
     * image are separated from the ROI by at least 63 bytes from each side.
     * However, this requires the whole ROI to be part of allocated 
     * memory. In case when the conditions above are not satisfied, the function
     * may decrease in speed slightly and will return 
     * NPP_MISALIGNED_DST_ROI_WARNING warning.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param srcQuad Source quadrangle
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param dstQuad Destination quadrangle
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_C1R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_16u_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_C1RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, three channels). 
     * @see nppiWarpPerspectiveQuad_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_C3R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_16u_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_C3RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, four channels). 
     * @see nppiWarpPerspectiveQuad_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_C4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_16u_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_C4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, four channels RGBA). 
     * @see nppiWarpPerspectiveQuad_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_AC4R(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_16u_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_AC4RNative(
        TypedPointer<Npp16u> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, three planes). 
     * @see nppiWarpPerspectiveQuad_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_P3R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_16u_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_P3RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (16bit unsigned integer, four planes). 
     * @see nppiWarpPerspectiveQuad_16u_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_16u_P4R(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_16u_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_16u_P4RNative(
        TypedPointer<Npp16u>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp16u>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, single channel). This
     * function operates using given transform coefficients that 
     * can be obtained by using nppiGetPerspectiveTransform function or set
     * explicitly. The function operates on source and destination regions 
     * of interest. The perspective warp function transforms the source image pixel
     * coordinates \f$(x,y)\f$ according to the following formulas:
     * \f[
     * X_{new} = \frac{C_{00} * x + C_{01} * y + C_{02}}{C_{20} * x + C_{21} * y + C_{22}} \qquad
     * Y_{new} = \frac{C_{10} * x + C_{11} * y + C_{12}}{C_{20} * x + C_{21} * y + C_{22}}
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetPerspectiveQuad and nppiGetPerspectiveBound can help
     * with destination ROI specification.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspective_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32f_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, three channels).
     * @see nppiWarpPerspective_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32f_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, four channels).
     * @see nppiWarpPerspective_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32f_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, four channels RGBA).
     * @see nppiWarpPerspective_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, three planes).
     * @see nppiWarpPerspective_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32f_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, four planes).
     * @see nppiWarpPerspective_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32f_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit float, single channel).
     * This function operates using given transform coefficients that 
     * can be obtained by using nppiGetPerspectiveTransform function or set
     * explicitly. Thus there is no need to invert coefficients in your application 
     * before calling WarpPerspectiveBack. The function operates on source and
     * destination regions of interest.
     * The perspective warp function transforms the source image pixel coordinates
     * \f$(x,y)\f$ according to the following formulas:
     * \f[
     * \frac{C_{00} * X_{new} + C_{01} * Y_{new} + C_{02}}{C_{20} * X_{new} + C_{21} * Y_{new} + C_{22}} = x  \qquad
     * \frac{C_{10} * X_{new} + C_{11} * Y_{new} + C_{12}}{C_{20} * X_{new} + C_{21} * Y_{new} + C_{22}} = y
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetPerspectiveQuad and nppiGetPerspectiveBound can help
     * with destination ROI specification.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32f_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit float, three channels).
     * @see nppiWarpPerspectiveBack_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32f_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit float, four channels).
     * @see nppiWarpPerspectiveBack_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32f_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit float, four channels RGBA).
     * @see nppiWarpPerspectiveBack_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit float, three planes).
     * @see nppiWarpPerspectiveBack_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32f_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit float, four planes).
     * @see nppiWarpPerspectiveBack_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32f_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, single channel).
     * This function performs perspective warping of a the specified
     * quadrangle in the source image to the specified quadrangle in the
     * destination image. The function nppiWarpPerspectiveQuad uses the same
     * formulas for pixel mapping as in nppiWarpPerspective function. The transform
     * coefficients are computed internally.
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param srcQuad Source quadrangle
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param dstQuad Destination quadrangle
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_C1R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32f_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_C1RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, three channels).
     * @see nppiWarpPerspectiveQuad_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_C3R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32f_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_C3RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, four channels).
     * @see nppiWarpPerspectiveQuad_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_C4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32f_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_C4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, four channels RGBA).
     * @see nppiWarpPerspectiveQuad_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_AC4R(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32f_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_AC4RNative(
        TypedPointer<Npp32f> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, three planes).
     * @see nppiWarpPerspectiveQuad_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_P3R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32f_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_P3RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit float, four planes).
     * @see nppiWarpPerspectiveQuad_32f_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32f_P4R(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32f_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32f_P4RNative(
        TypedPointer<Npp32f>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32f>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, single channel).
     * This function operates using given transform coefficients that 
     * can be obtained by using nppiGetPerspectiveTransform function or set
     * explicitly. The function operates on source and destination regions 
     * of interest. The perspective warp function transforms the source image pixel
     * coordinates \f$(x,y)\f$ according to the following formulas:
     * \f[
     * X_{new} = \frac{C_{00} * x + C_{01} * y + C_{02}}{C_{20} * x + C_{21} * y + C_{22}} \qquad
     * Y_{new} = \frac{C_{10} * x + C_{11} * y + C_{12}}{C_{20} * x + C_{21} * y + C_{22}}
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetPerspectiveQuad and nppiGetPerspectiveBound can help
     * with destination ROI specification.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs  Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspective_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32s_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, three channels).
     * @see nppiWarpPerspective_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32s_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, four channels).
     * @see nppiWarpPerspective_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32s_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, four channels RGBA).
     * @see nppiWarpPerspective_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, three planes).
     * @see nppiWarpPerspective_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32s_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, four planes).
     * @see nppiWarpPerspective_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspective_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspective_32s_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspective_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit signed integer, single
     * channel). This function operates using given transform coefficients that 
     * can be obtained by using nppiGetPerspectiveTransform function or set
     * explicitly. Thus there is no need to invert coefficients in your
     * application 
     * before calling WarpPerspectiveBack. The function operates on source
     * and destination regions of interest.
     * The perspective warp function transforms the source image pixel coordinates
     * \f$(x,y)\f$ according to the following formulas:
     * \f[
     * \frac{C_{00} * X_{new} + C_{01} * Y_{new} + C_{02}}{C_{20} * X_{new} + C_{21} * Y_{new} + C_{22}} = x  \qquad
     * \frac{C_{10} * X_{new} + C_{11} * Y_{new} + C_{12}}{C_{20} * X_{new} + C_{21} * Y_{new} + C_{22}} = y
     * \f]
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * The functions nppiGetPerspectiveQuad and nppiGetPerspectiveBound can help
     * with destination ROI specification.
     *
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param coeffs Perspective transform coefficients
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32s_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit signed integer, three channels).
     * @see nppiWarpPerspectiveBack_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32s_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit signed integer, four channels).
     * @see nppiWarpPerspectiveBack_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32s_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit signed integer, four channels RGBA).
     * @see nppiWarpPerspectiveBack_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit signed integer, three planes).
     * @see nppiWarpPerspectiveBack_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32s_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Inverse perspective transform of an image (32bit signed integer, four planes).
     * @see nppiWarpPerspectiveBack_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveBack_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveBack_32s_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, pDst, nDstStep, dstRoi, coeffs, eInterpolation));
    }
    private static native int nppiWarpPerspectiveBack_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] coeffs, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, single channel).
     * This function performs perspective warping of a the specified
     * quadrangle in the source image to the specified quadrangle in the
     * destination image. The function nppiWarpPerspectiveQuad uses the same
     * formulas for pixel mapping as in nppiWarpPerspective function. The transform
     * coefficients are computed internally.
     * The transformed part of the source image is resampled using the specified
     * interpolation method and written to the destination ROI.
     * 
     * @param pSrc \ref source_image_pointer.
     * @param oSrcSize Size of source image in pixels
     * @param nSrcStep \ref source_image_line_step.
     * @param srcRoi Source ROI
     * @param srcQuad Source quadrangle
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param dstRoi Destination ROI
     * @param dstQuad Destination quadrangle
     * @param eInterpolation Interpolation mode: can be NPPI_INTER_NN,
     *        NPPI_INTER_LINEAR or NPPI_INTER_CUBIC
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *         - #NPP_RECT_ERROR Indicates an error condition if width or height of
     *           the intersection of the srcRoi and source image is less than or
     *           equal to 1
     *         - #NPP_WRONG_INTERSECTION_ROI_ERROR Indicates an error condition if
     *           srcRoi has no intersection with the source image
     *         - #NPP_INTERPOLATION_ERROR Indicates an error condition if
     *           eInterpolation has an illegal value
     *         - #NPP_COEFF_ERROR Indicates an error condition if coefficient values
     *           are invalid
     *         - #NPP_WRONG_INTERSECTION_QUAD_WARNING Indicates a warning that no
     *           operation is performed if the transformed source ROI has no
     *           intersection with the destination ROI
     *         - #NPP_MISALIGNED_DST_ROI_WARNING Indicates a warning that the speed
     *           of primitive execution was reduced due to destination ROI
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_C1R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32s_C1RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_C1RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, three channels).
     * @see nppiWarpPerspectiveQuad_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_C3R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32s_C3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_C3RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, four channels).
     * @see nppiWarpPerspectiveQuad_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_C4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32s_C4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_C4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, four channels RGBA).
     * @see nppiWarpPerspectiveQuad_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_AC4R(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32s_AC4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_AC4RNative(
        TypedPointer<Npp32s> pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s> pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, three planes).
     * @see nppiWarpPerspectiveQuad_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_P3R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32s_P3RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_P3RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    /**
     * <pre>
     * Perspective transform of an image (32bit signed integer, four planes).
     * @see nppiWarpPerspectiveQuad_32s_C1R
     * </pre>
     */
    public static int nppiWarpPerspectiveQuad_32s_P4R(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation)
    {
        return checkResult(nppiWarpPerspectiveQuad_32s_P4RNative(pSrc, oSrcSize, nSrcStep, srcRoi, srcQuad, pDst, nDstStep, dstRoi, dstQuad, eInterpolation));
    }
    private static native int nppiWarpPerspectiveQuad_32s_P4RNative(
        TypedPointer<Npp32s>[] pSrc, 
        NppiSize oSrcSize, 
        int nSrcStep, 
        NppiRect srcRoi, 
        double[][] srcQuad, 
        TypedPointer<Npp32s>[] pDst, 
        int nDstStep, 
        NppiRect dstRoi, 
        double[][] dstQuad, 
        int eInterpolation);


    ///@}
    ///@} image_geometry_transforms
    /**
     * <pre>
     * @defgroup image_color_conversion Color Conversion
     *
     * Image color space and sample conversion operations.
     *
     * </pre>
     */
    ///@{
    /** @name RGBToYCbCr 
     *  RGB to YCbCr color conversion.
     */
    ///@{
    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to packed YCbCr color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRGBToYCbCr_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned RGB to 2 channel chroma packed YCbCr422 color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr422_8u_C3C2R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRGBToYCbCr422_8u_C3C2RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr422_8u_C3C2RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned packed RGB to planar YCbCr420 color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr420_8u_C3P3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRGBToYCbCr420_8u_C3P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr420_8u_C3P3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel planar 8-bit unsigned RGB to YCbCr color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRGBToYCbCr_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned RGB to YCbCr color conversion, ignoring Alpha.
     * 
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiRGBToYCbCr_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiRGBToYCbCr_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiRGBToYCbCr_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    ///@}
    /** @name YCbCrToRGB 
     *  YCbCr to RGB color conversion.
     */
    ///@{
    /**
     * <pre>
     * 3 channel 8-bit unsigned packed YCbCr to RGB color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCrToRGB_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiYCbCrToRGB_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCrToRGB_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr to RGB color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCrToRGB_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiYCbCrToRGB_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCrToRGB_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 4 channel 8-bit unsigned packed YCbCr to RGB color conversion, not affecting Alpha.
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCrToRGB_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiYCbCrToRGB_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCrToRGB_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 2 channel 8-bit unsigned YCbCr422 to 3 channel packed RGB color conversion.
     * images.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToRGB_8u_C2C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiYCbCr422ToRGB_8u_C2C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToRGB_8u_C2C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr420 to packed RGB color conversion.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToRGB_8u_P3C3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiYCbCr420ToRGB_8u_P3C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToRGB_8u_P3C3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI);


    ///@}
    /** @name Sample Pattern Conversion. 
     */
    ///@{
    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr:422 to YCbCr:420 resampling.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToYCbCr420_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiYCbCr422ToYCbCr420_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCbCr420_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr:422 to YCbCr:411 resampling.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr422ToYCbCr411_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiYCbCr422ToYCbCr411_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr422ToYCbCr411_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr:420 to YCbCr:422 resampling.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToYCbCr422_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiYCbCr420ToYCbCr422_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToYCbCr422_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int[] nDstStep, 
        NppiSize oSizeROI);


    /**
     * <pre>
     * 3 channel 8-bit unsigned planar YCbCr:420 to YCbCr:411 resampling.
     *
     * @param pSrc Array of pointers to the source image planes.
     * @param aSrcStep Array with distances in bytes between starts of consecutive
     *        lines of the source image planes.
     * @param pDstY \ref destination_image_pointer. Y-channel.
     * @param nDstYStep \ref destination_image_line_step. Y-channel.
     * @param pDstCbCr \ref destination_image_pointer. CbCr image.
     * @param nDstCbCrStep \ref destination_image_line_step. CbCr image.
     * @param oSizeROI \ref roi_specification.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiYCbCr420ToYCbCr411_8u_P3P2R(
        TypedPointer<Npp8u>[] pSrc, 
        int[] aSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI)
    {
        return checkResult(nppiYCbCr420ToYCbCr411_8u_P3P2RNative(pSrc, aSrcStep, pDstY, nDstYStep, pDstCbCr, nDstCbCrStep, oSizeROI));
    }
    private static native int nppiYCbCr420ToYCbCr411_8u_P3P2RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int[] aSrcStep, 
        TypedPointer<Npp8u> pDstY, 
        int nDstYStep, 
        TypedPointer<Npp8u> pDstCbCr, 
        int nDstCbCrStep, 
        NppiSize oSizeROI);


    ///@}
    /** @name Color Processing
     *  Color manipuliation functions.
     */
    ///@{
    /**
     * <pre>
     * 3 channel 8-bit unsigned color twist.
     * 
     * An input color twist matrix with floating-point pixel values is applied
     * within ROI.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param twist The color twist matrix with floating-point pixel values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiColorTwist32f_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist)
    {
        return checkResult(nppiColorTwist32f_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, twist));
    }
    private static native int nppiColorTwist32f_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist);


    /**
     * <pre>
     * 3 channel planar 8-bit unsigned color twist.
     *
     * An input color twist matrix with floating-point pixel values is applied
     * within ROI.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param twist The color twist matrix with floating-point pixel values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiColorTwist32f_8u_P3R(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist)
    {
        return checkResult(nppiColorTwist32f_8u_P3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, twist));
    }
    private static native int nppiColorTwist32f_8u_P3RNative(
        TypedPointer<Npp8u>[] pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u>[] pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist);


    /**
     * <pre>
     * 4 channel 8-bit unsigned color twist, not affecting Alpha.
     *
     * An input color twist matrix with floating-point pixel values is applied with
     * in ROI.
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param twist The color twist matrix with floating-point pixel values.
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiColorTwist32f_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist)
    {
        return checkResult(nppiColorTwist32f_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, twist));
    }
    private static native int nppiColorTwist32f_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        float[][] twist);


    /**
     * <pre>
     * 8-bit unsigned look-up-table color conversion.
     *
     * The LUT is derived from a set of user defined mapping points through linear
     * interpolation. 
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pValues Pointer to an array of user defined OUTPUT values
     * @param pLevels Pointer to an array of user defined INPUT values
     * @param nLevels Number of user defined input/output mapping points (levels)
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *        - #NPP_LUT_NUMBER_OF_LEVELS_ERROR if the number of levels is less than
     *         2.
     * </pre>
     */
    public static int nppiLUT_Linear_8u_C1R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pValues, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels)
    {
        return checkResult(nppiLUT_Linear_8u_C1RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pValues, pLevels, nLevels));
    }
    private static native int nppiLUT_Linear_8u_C1RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s> pValues, 
        TypedPointer<Npp32s> pLevels, 
        int nLevels);


    /**
     * <pre>
     * 3 channel 8-bit unsigned look-up-table color conversion.
     * 
     * The LUT is derived from a set of user defined mapping points through linear
     * interpolation. 
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pValues Double pointer to an [3] of arrays of user defined OUTPUT
     *        values per CHANNEL
     * @param pLevels Double pointer to an [3] of arrays of user defined INPUT
     *        values per CHANNEL
     * @param nLevels A [3] array of user defined input/output mapping points
     *        (levels) per CHANNEL
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *        - #NPP_LUT_NUMBER_OF_LEVELS_ERROR if the number of levels is less than
     *         2.
     * </pre>
     */
    public static int nppiLUT_Linear_8u_C3R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pValues, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels)
    {
        return checkResult(nppiLUT_Linear_8u_C3RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pValues, pLevels, nLevels));
    }
    private static native int nppiLUT_Linear_8u_C3RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pValues, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels);


    /**
     * <pre>
     * 4 channel 8-bit unsigned look-up-table color conversion, not affecting Alpha.
     *
     * The LUT is derived from a set of user defined mapping points through linear
     * interpolation. 
     * Alpha channel is the last channel and is not processed.
     *
     * @param pSrc \ref source_image_pointer.
     * @param nSrcStep \ref source_image_line_step.
     * @param pDst \ref destination_image_pointer.
     * @param nDstStep \ref destination_image_line_step.
     * @param oSizeROI \ref roi_specification.
     * @param pValues Double pointer to an [4] of arrays of user defined OUTPUT
     *        values per CHANNEL
     * @param pLevels Double pointer to an [4] of arrays of user defined INPUT
     *        values per CHANNEL
     * @param nLevels A [4] array of user defined input/output mapping points
     *        (levels) per CHANNEL
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     *        - #NPP_LUT_NUMBER_OF_LEVELS_ERROR if the number of levels is less than
     *         2.
     * </pre>
     */
    public static int nppiLUT_Linear_8u_AC4R(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pValues, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels)
    {
        return checkResult(nppiLUT_Linear_8u_AC4RNative(pSrc, nSrcStep, pDst, nDstStep, oSizeROI, pValues, pLevels, nLevels));
    }
    private static native int nppiLUT_Linear_8u_AC4RNative(
        TypedPointer<Npp8u> pSrc, 
        int nSrcStep, 
        TypedPointer<Npp8u> pDst, 
        int nDstStep, 
        NppiSize oSizeROI, 
        TypedPointer<Npp32s>[] pValues, 
        TypedPointer<Npp32s>[] pLevels, 
        int[] nLevels);


    /**
     * <pre>
     * Calculates the size of the temporary buffer for graph-cut with 4 neighborhood labeling.
     *
     * @see nppiGraphcutInitAlloc(), nppiGraphcut_32s8u().
     * 
     * @param oSize Graph size.
     * @param pBufSize Pointer to variable that returns the size of the
     *        temporary buffer. 
     *
     * @return
     *  NPP_SUCCESS Indicates no error. Any other value indicates an error
     *         or a warning
     *  NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *         has zero or negative value
     *  NPP_NULL_POINTER_ERROR Indicates an error condition if pBufSize
     *         pointer is NULL
     * </pre>
     */
    public static int nppiGraphcutGetSize(
        NppiSize oSize, 
        int[] pBufSize)
    {
        return checkResult(nppiGraphcutGetSizeNative(oSize, pBufSize));
    }
    private static native int nppiGraphcutGetSizeNative(
        NppiSize oSize, 
        int[] pBufSize);


    /**
     * <pre>
     * Calculates the size of the temporary buffer for graph-cut with 8 neighborhood labeling.
     *
     * @see nppiGraphcut8InitAlloc(), nppiGraphcut8_32s8u().
     * 
     * @param oSize Graph size.
     * @param pBufSize Pointer to variable that returns the size of the
     *        temporary buffer. 
     *
     * @return
     *  NPP_SUCCESS Indicates no error. Any other value indicates an error
     *         or a warning
     *  NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *         has zero or negative value
     *  NPP_NULL_POINTER_ERROR Indicates an error condition if pBufSize
     *         pointer is NULL
     * </pre>
     */
    public static int nppiGraphcut8GetSize(
        NppiSize oSize, 
        int[] pBufSize)
    {
        return checkResult(nppiGraphcut8GetSizeNative(oSize, pBufSize));
    }
    private static native int nppiGraphcut8GetSizeNative(
        NppiSize oSize, 
        int[] pBufSize);


    /**
     * <pre>
     * Initializes graph-cut state structure and allocates additional resources for graph-cut with 8 neighborhood labeling.
     *
     * @see nppiGraphcut_32s8u(), nppiGraphcutGetSize().
     * 
     * @param oSize Graph size
     * @param ppState Pointer to pointer to graph-cut state structure. 
     * @param pDeviceMem pDeviceMem to the sufficient amount of device memory. The CUDA runtime or NPP memory allocators
     *      must be used to allocate this memory. The minimum amount of device memory required
     *      to run graph-cut on a for a specific image size is computed by nppiGraphcutGetSize().
     *
     * @return
     *  NPP_SUCCESS Indicates no error. Any other value indicates an error
     *         or a warning
     *  NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *         has zero or negative value
     *  NPP_NULL_POINTER_ERROR Indicates an error condition if pBufSize
     *         pointer is NULL
     * </pre>
     */
    public static int nppiGraphcutInitAlloc(
        NppiSize oSize, 
        NppiGraphcutState[] ppState, 
        TypedPointer<Npp8u> pDeviceMem)
    {
        return checkResult(nppiGraphcutInitAllocNative(oSize, ppState, pDeviceMem));
    }
    private static native int nppiGraphcutInitAllocNative(
        NppiSize oSize, 
        NppiGraphcutState[] ppState, 
        TypedPointer<Npp8u> pDeviceMem);


    /**
     * <pre>
     * Allocates and initializes the graph-cut state structure and additional resources for graph-cut with 8 neighborhood labeling.
     *
     * @see nppiGraphcut8_32s8u(), nppiGraphcut8GetSize().
     * 
     * @param oSize Graph size
     * @param ppState Pointer to pointer to graph-cut state structure. 
     * @param pDeviceMem to the sufficient amount of device memory. The CUDA runtime or NPP memory allocators
     *      must be used to allocate this memory. The minimum amount of device memory required
     *      to run graph-cut on a for a specific image size is computed by nppiGraphcut8GetSize().
     *
     * @return
     *  NPP_SUCCESS Indicates no error. Any other value indicates an error
     *         or a warning
     *  NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *         has zero or negative value
     *  NPP_NULL_POINTER_ERROR Indicates an error condition if pBufSize
     *         pointer is NULL
     * </pre>
     */
    public static int nppiGraphcut8InitAlloc(
        NppiSize oSize, 
        NppiGraphcutState[] ppState, 
        TypedPointer<Npp8u> pDeviceMem)
    {
        return checkResult(nppiGraphcut8InitAllocNative(oSize, ppState, pDeviceMem));
    }
    private static native int nppiGraphcut8InitAllocNative(
        NppiSize oSize, 
        NppiGraphcutState[] ppState, 
        TypedPointer<Npp8u> pDeviceMem);


    /**
     * <pre>
     * Frees the additional resources of the graph-cut state structure.
     *
     * @see nppiGraphcutInitAlloc
     * @see nppiGraphcut8InitAlloc
     * 
     * @param pState Pointer to graph-cut state structure. 
     *
     * @return
     *  NPP_SUCCESS Indicates no error. Any other value indicates an error
     *         or a warning
     *  NPP_SIZE_ERROR Indicates an error condition if any image dimension
     *         has zero or negative value
     *  NPP_NULL_POINTER_ERROR Indicates an error condition if pState
     *         pointer is NULL
     * </pre>
     */
    public static int nppiGraphcutFree(
        NppiGraphcutState pState)
    {
        return checkResult(nppiGraphcutFreeNative(pState));
    }
    private static native int nppiGraphcutFreeNative(
        NppiGraphcutState pState);


    /**
     * <pre>
     * Graphcut of a flow network (32bit signed integer edge capacities). The
     * function computes the minimal cut (graphcut) of a 2D regular 4-connected
     * graph. 
     * The inputs are the capacities of the horizontal (in transposed form),
     * vertical and terminal (source and sink) edges. The capacities to source and
     * sink 
     * are stored as capacity differences in the terminals array 
     * ( terminals(x) = source(x) - sink(x) ). The implementation assumes that the
     * edge capacities 
     * for boundary edges that would connect to nodes outside the specified domain
     * are set to 0 (for example left(0,*) == 0). If this is not fulfilled the
     * computed labeling may be wrong!
     * The computed binary labeling is encoded as unsigned 8bit values (0 / 255).
     *
     * @see nppiGraphcutInitAlloc(), nppiGraphcutFree(), nppiGraphcutGetSize().
     *
     * @param pTerminals Pointer to differences of terminal edge capacities
     *        (terminal(x) = source(x) - sink(x))
     * @param pLeftTransposed Pointer to transposed left edge capacities
     *        (left(0,*) must be 0)
     * @param pRightTransposed Pointer to transposed right edge capacities
     *        (right(width-1,*) must be 0)
     * @param pTop Pointer to top edge capacities (top(*,0) must be 0)
     * @param pBottom Pointer to bottom edge capacities (bottom(*,height-1)
     *        must be 0)
     * @param nStep Step in bytes between any pair of sequential rows of edge
     *        capacities
     * @param nTransposedStep Step in bytes between any pair of sequential
     *        rows of tranposed edge capacities
     * @param size Graph size
     * @param pLabel Pointer to destination label image 
     * @param nLabelStep Step in bytes between any pair of sequential rows of
     *        label image
     * @param pState Pointer to graph-cut state structure. This structure must be
     *          initialized allocated and initialized using nppiGraphcutInitAlloc().
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGraphcut_32s8u(
        TypedPointer<Npp32s> pTerminals, 
        TypedPointer<Npp32s> pLeftTransposed, 
        TypedPointer<Npp32s> pRightTransposed, 
        TypedPointer<Npp32s> pTop, 
        TypedPointer<Npp32s> pBottom, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState)
    {
        return checkResult(nppiGraphcut_32s8uNative(pTerminals, pLeftTransposed, pRightTransposed, pTop, pBottom, nStep, nTransposedStep, size, pLabel, nLabelStep, pState));
    }
    private static native int nppiGraphcut_32s8uNative(
        TypedPointer<Npp32s> pTerminals, 
        TypedPointer<Npp32s> pLeftTransposed, 
        TypedPointer<Npp32s> pRightTransposed, 
        TypedPointer<Npp32s> pTop, 
        TypedPointer<Npp32s> pBottom, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState);


    /**
     * <pre>
     * Graphcut of a flow network (32bit signed integer edge capacities). The
     * function computes the minimal cut (graphcut) of a 2D regular 8-connected
     * graph. 
     * The inputs are the capacities of the horizontal (in transposed form),
     * vertical and terminal (source and sink) edges. The capacities to source and
     * sink 
     * are stored as capacity differences in the terminals array 
     * ( terminals(x) = source(x) - sink(x) ). The implementation assumes that the
     * edge capacities 
     * for boundary edges that would connect to nodes outside the specified domain
     * are set to 0 (for example left(0,*) == 0). If this is not fulfilled the
     * computed labeling may be wrong!
     * The computed binary labeling is encoded as unsigned 8bit values (0 / 255).
     *
     * @see nppiGraphcut8InitAlloc(), nppiGraphcutFree(), nppiGraphcut8GetSize().
     *
     * @param pTerminals Pointer to differences of terminal edge capacities
     *        (terminal(x) = source(x) - sink(x))
     * @param pLeftTransposed Pointer to transposed left edge capacities
     *        (left(0,*) must be 0)
     * @param pRightTransposed Pointer to transposed right edge capacities
     *        (right(width-1,*) must be 0)
     * @param pTop Pointer to top edge capacities (top(*,0) must be 0)
     * @param pTopLeft Pointer to top left edge capacities (topleft(*,0) 
     *        & topleft(0,*) must be 0)
     * @param pTopRight Pointer to top right edge capacities (topright(*,0)
     *        & topright(width-1,*) must be 0)
     * @param pBottom Pointer to bottom edge capacities (bottom(*,height-1)
     *        must be 0)
     * @param pBottomLeft Pointer to bottom left edge capacities 
     *        (bottomleft(*,height-1) && bottomleft(0,*) must be 0)
     * @param pBottomRight Pointer to bottom right edge capacities 
     *        (bottomright(*,height-1) && bottomright(width-1,*) must be 0)
     * @param nStep Step in bytes between any pair of sequential rows of edge
     *        capacities
     * @param nTransposedStep Step in bytes between any pair of sequential
     *        rows of tranposed edge capacities
     * @param size Graph size
     * @param pLabel Pointer to destination label image 
     * @param nLabelStep Step in bytes between any pair of sequential rows of
     *        label image
     * @param pState Pointer to graph-cut state structure. This structure must be
     *          initialized allocated and initialized using nppiGraphcut8InitAlloc().
     * @return
     *  \ref image_data_error_codes, \ref roi_error_codes
     * </pre>
     */
    public static int nppiGraphcut8_32s8u(
        TypedPointer<Npp32s> pTerminals, 
        TypedPointer<Npp32s> pLeftTransposed, 
        TypedPointer<Npp32s> pRightTransposed, 
        TypedPointer<Npp32s> pTop, 
        TypedPointer<Npp32s> pTopLeft, 
        TypedPointer<Npp32s> pTopRight, 
        TypedPointer<Npp32s> pBottom, 
        TypedPointer<Npp32s> pBottomLeft, 
        TypedPointer<Npp32s> pBottomRight, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState)
    {
        return checkResult(nppiGraphcut8_32s8uNative(pTerminals, pLeftTransposed, pRightTransposed, pTop, pTopLeft, pTopRight, pBottom, pBottomLeft, pBottomRight, nStep, nTransposedStep, size, pLabel, nLabelStep, pState));
    }
    private static native int nppiGraphcut8_32s8uNative(
        TypedPointer<Npp32s> pTerminals, 
        TypedPointer<Npp32s> pLeftTransposed, 
        TypedPointer<Npp32s> pRightTransposed, 
        TypedPointer<Npp32s> pTop, 
        TypedPointer<Npp32s> pTopLeft, 
        TypedPointer<Npp32s> pTopRight, 
        TypedPointer<Npp32s> pBottom, 
        TypedPointer<Npp32s> pBottomLeft, 
        TypedPointer<Npp32s> pBottomRight, 
        int nStep, 
        int nTransposedStep, 
        NppiSize size, 
        TypedPointer<Npp8u> pLabel, 
        int nLabelStep, 
        NppiGraphcutState pState);



}

